/*-------------------------------------------------------------------------*/
/*      Copyright (c)      Softing AG 2008                                 */
/*      Product:           EDD for CiDRA SONAR                             */
/*                                                                         */
/*      Device:            CiDRA SONAR     PA 2.20                         */
/*                                                                         */
/*      Communication:     PROFIBUS PA                                     */
/*      Description:       Definition for AIFB                             */
/*      Dictionary:                                                        */
/*      Revision           1.00                                            */
/*      Date:              2008/06/18                                      */
/*      Author:            SHR                                             */
/*-------------------------------------------------------------------------*/

#include "sonar_gen.inc"

BLOCK aifb
{
        TYPE    FUNCTION;
        NUMBER  1;
}


/*-------------------------------------------------------------------------*/
/*    AI function Block VARIABLE                                           */
/*-------------------------------------------------------------------------*/
/*    Standard Parameter (0-7)          (See PAprofile.pdf-3.3)            */
/*-------------------------------------------------------------------------*/

aifb_blk_reserve    LIKE VARIABLE   phys_blk_reserve
{
}

VARIABLE aifb_blk_object
{
        LABEL           [blk_block_object];
        HELP            [blk_block_object_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                {       2,      [blk_block_object_FUNCTION]     }
        }
        HANDLING        READ;
}

VARIABLE aifb_blk_parent_class
{
        LABEL           [blk_parent_class];
        HELP            [func_blk_parent_class_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                {       1,      [func_blk_parent_class_INPUT]   }
        }
        HANDLING        READ;
}

VARIABLE aifb_blk_class
{
        LABEL           [blk_class];
        HELP            [func_blk_class_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                {       1,      [func_blk_class_AI]     }
        }
        HANDLING        READ;
}

aifb_blk_dd_reference       LIKE VARIABLE   phys_blk_dd_reference
{
}

aifb_blk_dd_rev             LIKE VARIABLE   phys_blk_dd_rev
{
}

aifb_blk_profile            LIKE VARIABLE   phys_blk_profile
{
}

aifb_blk_profile_rev        LIKE VARIABLE   phys_blk_profile_rev
{
}

aifb_blk_execution_time     LIKE VARIABLE   phys_blk_execution_time
{
}

aifb_blk_num_parameters     LIKE VARIABLE   phys_blk_num_parameters
{
}

aifb_blk_index_view_1       LIKE VARIABLE   phys_blk_index_view_1
{
}

aifb_blk_num_view_lists     LIKE VARIABLE   phys_blk_num_view_lists
{
}
/*-------------------------------------------------------------------------*/
aifb_st_rev                 LIKE VARIABLE   phys_st_rev
{
        REDEFINE LABEL          "AI ST_REV";
}
/*-------------------------------------------------------------------------*/
aifb_tag_desc               LIKE VARIABLE   phys_tag_desc
{
        REDEFINE LABEL          "AIFB Tag";
}
/*-------------------------------------------------------------------------*/
aifb_strategy               LIKE VARIABLE   phys_strategy
{
}
/*-------------------------------------------------------------------------*/
aifb_alert_key              LIKE VARIABLE   phys_alert_key
{
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_target_mode
{
        LABEL           "Target Mode";
        HELP            [target_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_actual_mode
{
        LABEL           "Actual Mode";
        HELP            [actual_mode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}

VARIABLE aifb_permitted_mode
{
        LABEL           [permitted_mode];
        HELP            [permitted_mode_help];
        CLASS           CONTAINED;
        TYPE            BIT_ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}

VARIABLE aifb_normal_mode
{
        LABEL           [normal_mode];
        HELP            [normal_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
aifb_current_state_alarm_sum        LIKE VARIABLE   phys_current_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }

}

aifb_unacknowledged_state_alarm_sum LIKE VARIABLE   phys_unacknowledged_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }
}

aifb_unreported_state_alarm_sum     LIKE VARIABLE   phys_unreported_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }
}

aifb_disabled_state_alarm_sum       LIKE VARIABLE   phys_disabled_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }
}

/*-------------------------------------------------------------------------*/
/*    Function Parameter (8,10-35)                                         */
/*-------------------------------------------------------------------------*/
/* Batch Parameter (BATCH) standard for Function Blocks (DS-67)            */
/*-------------------------------------------------------------------------*/
VARIABLE aifb_batch_id                                /* index 8 */
{
        LABEL           [func_batch_id];
        HELP            [func_batch_id_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (4)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_batch_unit
{
        LABEL           [func_batch_unit];
        HELP            [func_batch_unit_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (2)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_batch_operation
{
        LABEL           [func_batch_operation];
        HELP            [func_batch_operation_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (2)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_batch_phase
{
        LABEL           [func_batch_phase];
        HELP            [func_batch_phase_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (2)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_out_value                                /* index 10 */
{
        LABEL           "Out";
        HELP            "AI Out Value";
        CLASS           OUTPUT & DYNAMIC;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING
        IF (aifb_actual_mode == BLOCK_MODE_MAN)
        {
                READ & WRITE;
        }
        ELSE
        {
                READ;
        }
}

VARIABLE aifb_out_status
{
        LABEL           [status_limit];
        HELP            [func_out_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_GENERAL
        }
        HANDLING
                IF (aifb_actual_mode == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_pv_upper_range_value                     /* index 11 */
{
        LABEL           "PV Upper Range";
        HELP            "PV Upper Range";
        CLASS           CONTAINED;
        TYPE          FLOAT
        {
                DEFAULT_VALUE   100.0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_pv_lower_range_value
{
        LABEL           "PV Lower Range";
        HELP            "PV Lower Range";
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_out_upper_range_value                      /* index 12 */
{
        LABEL           "OUT Upper Range";
        HELP            "OUT Upper Range";
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.005;
        }
        POST_WRITE_ACTIONS
        {
                method_write_limit_ai,
                method_write_fail_ai
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_out_lower_range_value
{
        LABEL           "OUT Lower Range";
        HELP            "OUT Lower Range";
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   -0.005;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_out_unit
{
        LABEL           "OUT Unit";
        HELP            "OUT Unit";
        CLASS           CONTAINED & SERVICE;
        TYPE            ENUMERATED (2)
        {
                DEFAULT_VALUE     1034;         /* just an example */
                { 1034, [unit_1034],   [unit_1034_help]},
                { 1038, [unit_1038],   [unit_1038_help]},
                { 1048, [unit_1048],   [unit_1048_help]},
                { 1010, [unit_1010],   [unit_1010_help]},
                { 1018, [unit_1018],   [unit_1018_help]},
                { 1049, [unit_1049],   [unit_1049_help]},
                { 1043, [unit_1043],   [unit_1043_help]},
                { 1067, [unit_1067],   [unit_1067_help]},
                { 1061, [unit_1061],   [unit_1061_help]},
                { 1347, [unit_1347],   [unit_1347_help]},
                { 1348, [unit_1348],   [unit_1348_help]},
                { 1349, [unit_1349],   [unit_1349_help]},
                { 1350, [unit_1350],   [unit_1350_help]},
                { 32772, [unit_32772],   [unit_32772_help]},
                { 1362, [unit_1362],   [unit_1362_help]},
                { 1363, [unit_1363],   [unit_1363_help]},
                { 1364, [unit_1364],   [unit_1364_help]},
                { 1365, [unit_1365],   [unit_1365_help]},
                { 32773, [unit_32773],   [unit_32773_help]},
                { 1351, [unit_1351],   [unit_1351_help]},
                { 1352, [unit_1352],   [unit_1352_help]},
                { 1353, [unit_1353],   [unit_1353_help]},
                { 1354, [unit_1354],   [unit_1354_help]},
                { 32774, [unit_32774],   [unit_32774_help]},
                { 32769, [unit_32769],   [unit_32769_help]},
                { 1063, [unit_1063],   [unit_1063_help]},
                { 32770, [unit_32770],   [unit_32770_help]},
                { 32775, [unit_32775],   [unit_32775_help]},
                { 1070, [unit_1070],   [unit_1070_help]},
                { 1073, [unit_1073],   [unit_1073_help]},
                { 32771, [unit_32771],   [unit_32771_help]},
                { 32776, [unit_32776],   [unit_32776_help]},
                { 1367, [unit_1367],   [unit_1367_help]},
                { 1368, [unit_1368],   [unit_1368_help]},
                { 1369, [unit_1369],   [unit_1369_help]},
                { 1370, [unit_1370],   [unit_1370_help]},
                { 32777, [unit_32777],   [unit_32777_help]},
                { 1356, [unit_1356],   [unit_1356_help]},
                { 1357, [unit_1357],   [unit_1357_help]},
                { 1358, [unit_1358],   [unit_1358_help]},
                { 1359, [unit_1359],   [unit_1359_help]},
                { 32778, [unit_32778],   [unit_32778_help]},
                { 32779, [unit_32779],   [unit_32779_help]},
                { 32780, [unit_32780],   [unit_32780_help]},
                { 32781, [unit_32781],   [unit_32781_help]},
                { 32782, [unit_32782],   [unit_32782_help]},
                { 32783, [unit_32783],   [unit_32783_help]},
                { 1342, [unit_1342],   [unit_1342_help]}
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_out_decimal_point
{
        LABEL           [decimal_point];
        HELP            [decimal_point_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   2;
                {       0,   "0"        },
                {       1,   "1"        },
                {       2,   "2"        },
                {       3,   "3"        },
                {       4,   "4"        },
                {       5,   "5"        },
                {       6,   "6"        }
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_lin_type                                 /* index 13 */
{
        LABEL           [trans_lin_type];
        HELP            [trans_lin_type_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;                      /* see PAprofile.pdf-3.8 */
                {       0, "No Linearisation."  },
                {       10,[lin_type_SQUARE_ROOT] }
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_channel                                      /* index 14 */
{
        LABEL           [func_channel];
        HELP            [func_channel_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (2)
        {
                DEFAULT_VALUE 296;
                { 296, "Flow Rate" },
                { 297, "Gas Volume Fraction"},
                { 298, "Speed of Sound"},
                { 299, "Sensorhead Temperature"},
                { 300, "Total Flow"},
                { 301, "Acoustic Level"},
                { 302, "Output 0"},
                { 303, "Output 1"},
                { 304, "Output 2"}
        }
        HANDLING        READ&WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_pv_ftime                                   /* index 16 */
{
        LABEL           [func_pv_ftime];
        HELP            [func_pv_ftime_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;            /* 0-24s */
        }
        CONSTANT_UNIT   "s";
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_FSafeType                                /* index 17 */
{
        LABEL           "Fail Safe Type";
        HELP            "Fail Safe Type";
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                DEFAULT_VALUE    1;
                { 0,[fsave_value]},
                { 1,[last_valid_OUT]},
                { 2,[OUT_wrong_value]}
        }
        HANDLING  READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_FSafeValue                                 /* index 18 */
{
        LABEL     "Fail Safe Value";
        HELP      "Fail Safe Value";
        CLASS     CONTAINED;
        TYPE      FLOAT
        {
                DEFAULT_VALUE  0.0;
        }
        HANDLING  READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_alarm_hys                                    /* index 19 */
{
        /* ST_REV */
        LABEL           [limit_hysteresis];
        HELP            [limit_hysteresis_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE  0.5;
        }
        CONSTANT_UNIT    "%";
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_hi_hi_lim                                    /* index 21 */
{
        LABEL           [limit_hi_hi];
        HELP            [limit_hi_hi_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    100.0;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_hi_lim                                       /* index 23 */
{
        /* ST_REV */
        LABEL           [limit_hi];
        HELP            [limit_hi_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    99.5;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_lo_lim                                       /* index 25 */
{
        LABEL           [limit_lo];
        HELP            [limit_lo_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    0.5;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_lo_lo_lim                                    /* index 27 */
{
        LABEL           [limit_lo_lo];
        HELP            [limit_lo_lo_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    0.0;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_hi_hi_alm_unacknowledged                     /* index 30 */
{
        LABEL           [limit_alarm_unacknowledged];
        HELP            [limit_alarm_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_hi_hi_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_hi_hi_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_ALARM]  },
                {       1,      [limit_state_HI_HI]     }
        }
        HANDLING        READ;
}

VARIABLE aifb_hi_hi_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_hi_hi_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_hi_hi_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_hi_hi_alm_value
{
        LABEL           [limit_alarm_value];
        HELP            [limit_hi_hi_alarm_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_hi_alm_unacknowledged                        /* index 31 */
{
        LABEL           [limit_warn_unacknowledged];
        HELP            [limit_warn_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_hi_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_hi_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_WARNING]        },
                {       1,      [limit_state_HI]                }
        }
        HANDLING        READ;
}

VARIABLE aifb_hi_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_hi_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_hi_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_hi_alm_value
{
        LABEL           [limit_warn_value];
        HELP            [limit_hi_warn_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_lo_alm_unacknowledged                        /* index 32 */
{
        LABEL           [limit_warn_unacknowledged];
        HELP            [limit_warn_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_lo_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_lo_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_WARNING]        },
                {       1,      [limit_state_LO]                }
        }
        HANDLING        READ;
}

VARIABLE aifb_lo_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_lo_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_lo_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_lo_alm_value
{
        LABEL           [limit_warn_value];
        HELP            [limit_lo_warn_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_lo_lo_alm_unacknowledged                     /* index 33 */
{
        LABEL           [limit_alarm_unacknowledged];
        HELP            [limit_alarm_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_lo_lo_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_lo_lo_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_ALARM]          },
                {       1,      [limit_state_LO_LO]             }
        }
        HANDLING        READ;
}

VARIABLE aifb_lo_lo_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_lo_lo_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_lo_lo_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_lo_lo_alm_value
{
        LABEL           [limit_alarm_value];
        HELP            [limit_lo_lo_alarm_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_simulate_status                              /* index 34 */
{
        LABEL           [status_limit];
        HELP            [func_simulate_status_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_GENERAL
        }
        HANDLING        READ & WRITE;
}


VARIABLE aifb_simulate_value
{
        LABEL           [func_simulate_value];
        HELP            [func_ai_simulate_value_help];
        CLASS           CONTAINED;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_simulation_enabled
{
        LABEL           [func_simulation_enabled];
        HELP            [func_simulation_enabled_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      "disabled"              },
                {       1,      "enabled"               }
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_out_unit_text                                /* index 35 */
{
        /* ST_REV */
        LABEL   [func_out_unit_text] ;
        HELP    [func_out_unit_text_help] ;
        CLASS CONTAINED ;
        TYPE ASCII(16) ;
        HANDLING READ & WRITE ;
}

/*-------------------------------------------------------------------------*/
/*    Function Block COMMAND (AI)                                          */
/*-------------------------------------------------------------------------*/
/*    Standard Parameter (0-8)                                             */
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_blk
{
        BLOCK aifb;
        INDEX 0;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_blk_reserve,
                        aifb_blk_object,
                        aifb_blk_parent_class,
                        aifb_blk_class,
                        aifb_blk_dd_reference,
                        aifb_blk_dd_rev,
                        aifb_blk_profile,
                        aifb_blk_profile_rev,
                        aifb_blk_execution_time,
                        aifb_blk_num_parameters,
                        aifb_blk_index_view_1,
                        aifb_blk_num_view_lists
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_st_rev
{
        BLOCK aifb;
        INDEX 1;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_st_rev
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_tag_desc
{
        BLOCK aifb;
        INDEX 2;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_tag_desc
                }
        }
}

COMMAND write_aifb_tag_desc
{
        BLOCK aifb;
        INDEX 2;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_tag_desc
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_strategy
{
        BLOCK aifb;
        INDEX 3;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_strategy
                }
        }
}

COMMAND write_aifb_strategy
{
        BLOCK aifb;
        INDEX 3;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_strategy
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_alert_key
{
        BLOCK aifb;
        INDEX 4;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_alert_key
                }
        }
}

COMMAND write_aifb_alert_key
{
        BLOCK aifb;
        INDEX 4;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_alert_key
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_target_mode
{
        BLOCK aifb;
        INDEX 5;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_target_mode
                }
        }
}

COMMAND write_aifb_target_mode
{
        BLOCK aifb;
        INDEX 5;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_target_mode
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_mode
{
        BLOCK aifb;
        INDEX 6;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                         aifb_actual_mode,
                         aifb_permitted_mode,
                         aifb_normal_mode
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_alarm
{
        BLOCK aifb;
        INDEX 7;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_current_state_alarm_sum,
                        aifb_unacknowledged_state_alarm_sum,
                        aifb_unreported_state_alarm_sum,
                        aifb_disabled_state_alarm_sum
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_batch_information
{
        BLOCK aifb;
        INDEX 8;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_batch_id,
                        aifb_batch_unit,
                        aifb_batch_operation,
                        aifb_batch_phase
                }
        }
}

COMMAND write_aifb_batch_information
{
        BLOCK aifb;
        INDEX 8;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_batch_id,
                        aifb_batch_unit,
                        aifb_batch_operation,
                        aifb_batch_phase
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
/*    Function Parameter (10-35)                                           */
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_out
{
        BLOCK aifb;
        INDEX 10;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_out_value,
                        aifb_out_status
                }
        }
}

COMMAND write_aifb_out
{
        BLOCK aifb;
        INDEX 10;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_out_value,
                        aifb_out_status
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_pv
{
        BLOCK aifb;
        INDEX 11;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_pv_upper_range_value,
                        aifb_pv_lower_range_value
                }
        }
}

COMMAND write_aifb_pv
{
        BLOCK aifb;
        INDEX 11;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_pv_upper_range_value,
                        aifb_pv_lower_range_value
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_out_scale
{
        BLOCK aifb;
        INDEX 12;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_out_upper_range_value,
                        aifb_out_lower_range_value,
                        aifb_out_unit,
                        aifb_out_decimal_point
                }
        }
}

COMMAND write_aifb_out_scale
{
        BLOCK aifb;
        INDEX 12;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_out_upper_range_value,
                        aifb_out_lower_range_value,
                        aifb_out_unit,
                        aifb_out_decimal_point
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_lin_type
{
        BLOCK aifb;
        INDEX 13;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_lin_type
                }
        }
}

COMMAND write_aifb_lin_type
{
        BLOCK aifb;
        INDEX 13;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_lin_type
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_channel
{
        BLOCK aifb;
        INDEX 14;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_channel
                }
        }
}

COMMAND write_aifb_channel
{
        BLOCK aifb;
        INDEX 14;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_channel
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_pv_ftime
{
        BLOCK aifb;
        INDEX 16;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_pv_ftime
                }
        }
}

COMMAND write_aifb_pv_ftime
{
        BLOCK aifb;
        INDEX 16;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_pv_ftime
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_FSafeType
{
        BLOCK aifb;
        INDEX 17;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_FSafeType
                }
        }
}

COMMAND write_aifb_FSafeType
{
        BLOCK aifb;
        INDEX 17;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_FSafeType
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_FSafeValue
{
        BLOCK aifb;
        INDEX 18;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_FSafeValue
                }
        }
}

COMMAND write_aifb_FSafeValue
{
        BLOCK aifb;
        INDEX 18;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_FSafeValue
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_alarm_hys
{
        BLOCK aifb;
        INDEX 19;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_alarm_hys
                }
        }
}


COMMAND write_aifb_alarm_hys
{
        BLOCK aifb;
        INDEX 19;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_alarm_hys
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_hi_hi_lim
{
        BLOCK aifb;
        INDEX 21;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_hi_hi_lim
                }
        }
}

COMMAND write_aifb_hi_hi_lim
{
        BLOCK aifb;
        INDEX 21;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_hi_hi_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_hi_lim
{
        BLOCK aifb;
        INDEX 23;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_hi_lim
                }
        }
}

COMMAND write_aifb_hi_lim
{
        BLOCK aifb;
        INDEX 23;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_hi_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_lo_lim
{
        BLOCK aifb;
        INDEX 25;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_lo_lim
                }
        }
}

COMMAND write_aifb_lo_lim
{
        BLOCK aifb;
        INDEX 25;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_lo_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_lo_lo_lim
{
        BLOCK aifb;
        INDEX 27;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_lo_lo_lim
                }
        }
}

COMMAND write_aifb_lo_lo_lim
{
        BLOCK aifb;
        INDEX 27;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_lo_lo_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_hi_hi_alm
{
        BLOCK aifb;
        INDEX 30;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_hi_hi_alm_unacknowledged,
                        aifb_hi_hi_alm_state,
                        aifb_hi_hi_alm_time_stamp,
                        aifb_hi_hi_alm_subcode,
                        aifb_hi_hi_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_hi_alm
{
        BLOCK aifb;
        INDEX 31;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_hi_alm_unacknowledged,
                        aifb_hi_alm_state,
                        aifb_hi_alm_time_stamp,
                        aifb_hi_alm_subcode,
                        aifb_hi_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_lo_alm
{
        BLOCK aifb;
        INDEX 32;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_lo_alm_unacknowledged,
                        aifb_lo_alm_state,
                        aifb_lo_alm_time_stamp,
                        aifb_lo_alm_subcode,
                        aifb_lo_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_lo_lo_alm
{
        BLOCK aifb;
        INDEX 33;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_lo_lo_alm_unacknowledged,
                        aifb_lo_lo_alm_state,
                        aifb_lo_lo_alm_time_stamp,
                        aifb_lo_lo_alm_subcode,
                        aifb_lo_lo_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_simulate
{
        BLOCK aifb;
        INDEX 34;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_simulate_status,
                        aifb_simulate_value,
                        aifb_simulation_enabled
                }
        }
}

COMMAND write_aifb_simulate
{
        BLOCK aifb;
        INDEX 34;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_simulate_status,
                        aifb_simulate_value,
                        aifb_simulation_enabled
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/

COMMAND read_aifb_out_unit_text
{
        BLOCK aifb;
        INDEX 35;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_out_unit_text
                }
        }
}

COMMAND write_aifb_out_unit_text
{
        BLOCK aifb;
        INDEX 35;
        OPERATION WRITE ;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_out_unit_text
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------*/
/* Function Block 1: AI                                                    */
/*-------------------------------------------------------------------------*/
UNIT AI_OUT_UNIT
{
        aifb_out_unit:

        aifb_out_value,                \
        aifb_out_upper_range_value,    \
        aifb_out_lower_range_value,    \
        aifb_hi_hi_lim,                \
        aifb_hi_lim,                   \
        aifb_lo_lim,                   \
        aifb_lo_lo_lim,                \
        aifb_hi_hi_alm_value,          \
        aifb_hi_alm_value,             \
        aifb_lo_alm_value,             \
        aifb_lo_lo_alm_value,          \
        aifb_FSafeValue
}
