/*-------------------------------------------------------------------------*/
/*      Copyright (c)      Softing AG 2008                                 */
/*      Product:           EDD for CiDRA SONAR                             */
/*                                                                         */
/*      Device:            CiDRA SONAR     PA 2.20                         */
/*                                                                         */
/*      Communication:     PROFIBUS PA                                     */
/*      Description:       Definition for AIFB                             */
/*      Dictionary:                                                        */
/*      Revision           1.00                                            */
/*      Date:              2008/06/18                                      */
/*      Author:            SHR                                             */
/*-------------------------------------------------------------------------*/

#include "sonar_gen.inc"

BLOCK aifb_7
{
        TYPE    FUNCTION;
        NUMBER  7;
}


/*-------------------------------------------------------------------------*/
/*    AI function Block VARIABLE                                           */
/*-------------------------------------------------------------------------*/
/*    Standard Parameter (0-7)          (See PAprofile.pdf-3.3)            */
/*-------------------------------------------------------------------------*/

aifb_7_blk_reserve    LIKE VARIABLE   phys_blk_reserve
{
}

aifb_7_blk_object     LIKE VARIABLE aifb_blk_object
{
}

aifb_7_blk_parent_class LIKE  VARIABLE aifb_blk_parent_class
{
}

aifb_7_blk_class    LIKE  VARIABLE aifb_blk_class
{
}

aifb_7_blk_dd_reference       LIKE VARIABLE   phys_blk_dd_reference
{
}

aifb_7_blk_dd_rev             LIKE VARIABLE   phys_blk_dd_rev
{
}

aifb_7_blk_profile            LIKE VARIABLE   phys_blk_profile
{
}

aifb_7_blk_profile_rev        LIKE VARIABLE   phys_blk_profile_rev
{
}

aifb_7_blk_execution_time     LIKE VARIABLE   phys_blk_execution_time
{
}

aifb_7_blk_num_parameters     LIKE VARIABLE   phys_blk_num_parameters
{
}

aifb_7_blk_index_view_1       LIKE VARIABLE   phys_blk_index_view_1
{
}

aifb_7_blk_num_view_lists     LIKE VARIABLE   phys_blk_num_view_lists
{
}
/*-------------------------------------------------------------------------*/
aifb_7_st_rev                 LIKE VARIABLE   phys_st_rev
{
        REDEFINE LABEL          "AI ST_REV";
}
/*-------------------------------------------------------------------------*/
aifb_7_tag_desc               LIKE VARIABLE   phys_tag_desc
{
        REDEFINE LABEL          "AIFB Tag";
}
/*-------------------------------------------------------------------------*/
aifb_7_strategy               LIKE VARIABLE   phys_strategy
{
}
/*-------------------------------------------------------------------------*/
aifb_7_alert_key              LIKE VARIABLE   phys_alert_key
{
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_target_mode
{
        LABEL           "Target Mode";
        HELP            [target_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ & WRITE;

}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_actual_mode
{
        LABEL           "Actual Mode";
        HELP            [actual_mode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}

VARIABLE aifb_7_permitted_mode
{
        LABEL           [permitted_mode];
        HELP            [permitted_mode_help];
        CLASS           CONTAINED;
        TYPE            BIT_ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}

VARIABLE aifb_7_normal_mode
{
        LABEL           [normal_mode];
        HELP            [normal_mode_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]             },
                {       0x10,   [mode_MAN]              },
                {       0x80,   [mode_OUT_OF_SERVICE]   }
        }
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
aifb_7_current_state_alarm_sum        LIKE VARIABLE   phys_current_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }

}

aifb_7_unacknowledged_state_alarm_sum LIKE VARIABLE   phys_unacknowledged_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }
}

aifb_7_unreported_state_alarm_sum     LIKE VARIABLE   phys_unreported_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }
}

aifb_7_disabled_state_alarm_sum       LIKE VARIABLE   phys_disabled_state_alarm_sum
{
        REDEFINE TYPE           BIT_ENUMERATED (2)
        {
                {       0x0000, [limit_state_NO_ALARM]  },
                {       0x0200, [limit_state_HI_HI]     },
                {       0x0400, [limit_state_HI]        },
                {       0x0800, [limit_state_LO_LO]     },
                {       0x1000, [limit_state_LO]        },
                {       0x8000, [limit_state_ST_REV]    }
        }
}

/*-------------------------------------------------------------------------*/
/*    Function Parameter (8,10-35)                                         */
/*-------------------------------------------------------------------------*/
/* Batch Parameter (BATCH) standard for Function Blocks (DS-67)            */
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_batch_id                                /* index 8 */
{
        LABEL           [func_batch_id];
        HELP            [func_batch_id_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (4)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_batch_unit
{
        LABEL           [func_batch_unit];
        HELP            [func_batch_unit_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (2)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_batch_operation
{
        LABEL           [func_batch_operation];
        HELP            [func_batch_operation_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (2)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_batch_phase
{
        LABEL           [func_batch_phase];
        HELP            [func_batch_phase_help];
        CLASS           CONTAINED;
        TYPE            UNSIGNED_INTEGER (2)
        {
                DEFAULT_VALUE   0;
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_out_value                                /* index 10 */
{
        LABEL           "Out";
        HELP            "AI Out Value";
        CLASS           OUTPUT & DYNAMIC;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING
        IF (aifb_7_actual_mode == BLOCK_MODE_MAN)
        {
                READ & WRITE;
        }
        ELSE
        {
                READ;
        }
}

VARIABLE aifb_7_out_status
{
        LABEL           [status_limit];
        HELP            [func_out_status_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_GENERAL
        }
        HANDLING
                IF (aifb_7_actual_mode == BLOCK_MODE_MAN)
                {
                        READ & WRITE;
                }
                ELSE
                {
                        READ;
                }
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_pv_upper_range_value                     /* index 11 */
{
        LABEL           "PV Upper Range";
        HELP            "PV Upper Range";
        CLASS           CONTAINED;
        TYPE          FLOAT
        {
                DEFAULT_VALUE   100.0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_pv_lower_range_value
{
        LABEL           "PV Lower Range";
        HELP            "PV Lower Range";
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_out_upper_range_value                      /* index 12 */
{
        LABEL           "OUT Upper Range";
        HELP            "OUT Upper Range";
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.005;
        }
        POST_WRITE_ACTIONS
        {
                method_write_limit_ai,
                method_write_fail_ai
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_out_lower_range_value
{
        LABEL           "OUT Lower Range";
        HELP            "OUT Lower Range";
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   -0.005;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_out_unit
{
        LABEL           "OUT Unit";
        HELP            "OUT Unit";
        CLASS           CONTAINED & SERVICE;
        TYPE            ENUMERATED (2)
        {
                DEFAULT_VALUE     1034;         /* just an example */
				UNIT_LIST
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_out_decimal_point
{
        LABEL           [decimal_point];
        HELP            [decimal_point_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   2;
                {       0,   "0"        },
                {       1,   "1"        },
                {       2,   "2"        },
                {       3,   "3"        },
                {       4,   "4"        },
                {       5,   "5"        },
                {       6,   "6"        }
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_lin_type                                 /* index 13 */
{
        LABEL           [trans_lin_type];
        HELP            [trans_lin_type_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;                      /* see PAprofile.pdf-3.8 */
                {       0, "No Linearisation."  },
                {       10,[lin_type_SQUARE_ROOT] }
        }
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_channel                                      /* index 14 */
{
        LABEL           [func_channel];
        HELP            [func_channel_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (2)
        {
                DEFAULT_VALUE 296;
                { 296, "Flow Rate" },
                { 297, "Gas Volume Fraction"},
                { 298, "Speed of Sound"},
                { 299, "Sensorhead Temperature"},
                { 300, "Total Flow"},
                { 301, "Acoustic Level"},
                { 302, "Output 0"},
                { 303, "Output 1"},
                { 304, "Output 2"}
        }
        HANDLING        READ&WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_pv_ftime                                   /* index 16 */
{
        LABEL           [func_pv_ftime];
        HELP            [func_pv_ftime_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE   0.0;            /* 0-24s */
        }
        CONSTANT_UNIT   "s";
        HANDLING        READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_FSafeType                                /* index 17 */
{
        LABEL           "Fail Safe Type";
        HELP            "Fail Safe Type";
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                DEFAULT_VALUE    1;
                { 0,[fsave_value]},
                { 1,[last_valid_OUT]},
                { 2,[OUT_wrong_value]}
        }
        HANDLING  READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_FSafeValue                                 /* index 18 */
{
        LABEL     "Fail Safe Value";
        HELP      "Fail Safe Value";
        CLASS     CONTAINED;
        TYPE      FLOAT
        {
                DEFAULT_VALUE  0.0;
        }
        HANDLING  READ & WRITE;
}

/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_alarm_hys                                    /* index 19 */
{
        LABEL           [limit_hysteresis];
        HELP            [limit_hysteresis_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE  0.5;
        }
        CONSTANT_UNIT    "%";
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_hi_hi_lim                                    /* index 21 */
{
        LABEL           [limit_hi_hi];
        HELP            [limit_hi_hi_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    100.0;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_hi_lim                                       /* index 23 */
{
        LABEL           [limit_hi];
        HELP            [limit_hi_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    99.5;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_lo_lim                                       /* index 25 */
{
        LABEL           [limit_lo];
        HELP            [limit_lo_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    0.5;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_lo_lo_lim                                    /* index 27 */
{
        LABEL           [limit_lo_lo];
        HELP            [limit_lo_lo_help];
        CLASS           CONTAINED;
        TYPE            FLOAT
        {
                DEFAULT_VALUE    0.0;
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_hi_hi_alm_unacknowledged                     /* index 30 */
{
        LABEL           [limit_alarm_unacknowledged];
        HELP            [limit_alarm_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_7_hi_hi_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_hi_hi_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_ALARM]  },
                {       1,      [limit_state_HI_HI]     }
        }
        HANDLING        READ;
}

VARIABLE aifb_7_hi_hi_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_7_hi_hi_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_hi_hi_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_7_hi_hi_alm_value
{
        LABEL           [limit_alarm_value];
        HELP            [limit_hi_hi_alarm_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_hi_alm_unacknowledged                        /* index 31 */
{
        LABEL           [limit_warn_unacknowledged];
        HELP            [limit_warn_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_7_hi_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_hi_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_WARNING]        },
                {       1,      [limit_state_HI]                }
        }
        HANDLING        READ;
}

VARIABLE aifb_7_hi_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_7_hi_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_hi_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_7_hi_alm_value
{
        LABEL           [limit_warn_value];
        HELP            [limit_hi_warn_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_lo_alm_unacknowledged                        /* index 32 */
{
        LABEL           [limit_warn_unacknowledged];
        HELP            [limit_warn_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_7_lo_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_lo_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_WARNING]        },
                {       1,      [limit_state_LO]                }
        }
        HANDLING        READ;
}

VARIABLE aifb_7_lo_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_7_lo_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_lo_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_7_lo_alm_value
{
        LABEL           [limit_warn_value];
        HELP            [limit_lo_warn_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_lo_lo_alm_unacknowledged                     /* index 33 */
{
        LABEL           [limit_alarm_unacknowledged];
        HELP            [limit_alarm_unacknowledged_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (1);
        HANDLING        READ;
}

VARIABLE aifb_7_lo_lo_alm_state
{
        LABEL           [limit_state];
        HELP            [limit_lo_lo_state_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      [limit_state_NO_ALARM]          },
                {       1,      [limit_state_LO_LO]             }
        }
        HANDLING        READ;
}

VARIABLE aifb_7_lo_lo_alm_time_stamp
{
        LABEL           [limit_time_stamp];
        HELP            [limit_time_stamp_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            TIME;
        HANDLING        READ;
}

VARIABLE aifb_7_lo_lo_alm_subcode
{
        LABEL           [limit_subcode];
        HELP            [limit_lo_lo_subcode_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            UNSIGNED_INTEGER (2);
        HANDLING        READ;
}

VARIABLE aifb_7_lo_lo_alm_value
{
        LABEL           [limit_alarm_value];
        HELP            [limit_lo_lo_alarm_value_help];
        CLASS           CONTAINED & DYNAMIC;
        TYPE            FLOAT;
        HANDLING        READ;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_simulate_status                              /* index 34 */
{
        LABEL           [status_limit];
        HELP            [func_simulate_status_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                STATUS_GENERAL
        }
        HANDLING        READ & WRITE;
}


VARIABLE aifb_7_simulate_value
{
        LABEL           [func_simulate_value];
        HELP            [func_ai_simulate_value_help];
        CLASS           CONTAINED;
        TYPE        FLOAT
        {
                DEFAULT_VALUE   0.0;
        }
        HANDLING        READ & WRITE;
}

VARIABLE aifb_7_simulation_enabled
{
        LABEL           [func_simulation_enabled];
        HELP            [func_simulation_enabled_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED (1)
        {
                DEFAULT_VALUE   0;
                {       0,      "disabled"              },
                {       1,      "enabled"               }
        }
        HANDLING        READ & WRITE;
}
/*-------------------------------------------------------------------------*/
VARIABLE aifb_7_out_unit_text                                /* index 35 */
{
        LABEL   [func_out_unit_text] ;
        HELP    [func_out_unit_text_help] ;
        CLASS CONTAINED ;
        TYPE ASCII(16) ;
        HANDLING READ & WRITE ;
}

/*-------------------------------------------------------------------------*/
/*    Function Block COMMAND (AI)                                          */
/*-------------------------------------------------------------------------*/
/*    Standard Parameter (0-8)                                             */
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_blk
{
        BLOCK aifb_7;
        INDEX 0;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_blk_reserve,
                        aifb_7_blk_object,
                        aifb_7_blk_parent_class,
                        aifb_7_blk_class,
                        aifb_7_blk_dd_reference,
                        aifb_7_blk_dd_rev,
                        aifb_7_blk_profile,
                        aifb_7_blk_profile_rev,
                        aifb_7_blk_execution_time,
                        aifb_7_blk_num_parameters,
                        aifb_7_blk_index_view_1,
                        aifb_7_blk_num_view_lists
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_st_rev
{
        BLOCK aifb_7;
        INDEX 1;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_st_rev
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_tag_desc
{
        BLOCK aifb_7;
        INDEX 2;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_tag_desc
                }
        }
}

COMMAND write_aifb_7_tag_desc
{
        BLOCK aifb_7;
        INDEX 2;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_tag_desc
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_strategy
{
        BLOCK aifb_7;
        INDEX 3;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_strategy
                }
        }
}

COMMAND write_aifb_7_strategy
{
        BLOCK aifb_7;
        INDEX 3;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_strategy
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_alert_key
{
        BLOCK aifb_7;
        INDEX 4;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_alert_key
                }
        }
}

COMMAND write_aifb_7_alert_key
{
        BLOCK aifb_7;
        INDEX 4;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_alert_key
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_target_mode
{
        BLOCK aifb_7;
        INDEX 5;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_target_mode
                }
        }
}

COMMAND write_aifb_7_target_mode
{
        BLOCK aifb_7;
        INDEX 5;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_target_mode
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_mode
{
        BLOCK aifb_7;
        INDEX 6;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                         aifb_7_actual_mode,
                         aifb_7_permitted_mode,
                         aifb_7_normal_mode
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_alarm
{
        BLOCK aifb_7;
        INDEX 7;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_current_state_alarm_sum,
                        aifb_7_unacknowledged_state_alarm_sum,
                        aifb_7_unreported_state_alarm_sum,
                        aifb_7_disabled_state_alarm_sum
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_batch_information
{
        BLOCK aifb_7;
        INDEX 8;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_batch_id,
                        aifb_7_batch_unit,
                        aifb_7_batch_operation,
                        aifb_7_batch_phase
                }
        }
}

COMMAND write_aifb_7_batch_information
{
        BLOCK aifb_7;
        INDEX 8;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_batch_id,
                        aifb_7_batch_unit,
                        aifb_7_batch_operation,
                        aifb_7_batch_phase
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
/*    Function Parameter (10-35)                                           */
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_out
{
        BLOCK aifb_7;
        INDEX 10;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_out_value,
                        aifb_7_out_status
                }
        }
}

COMMAND write_aifb_7_out
{
        BLOCK aifb_7;
        INDEX 10;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_out_value,
                        aifb_7_out_status
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_pv
{
        BLOCK aifb_7;
        INDEX 11;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_pv_upper_range_value,
                        aifb_7_pv_lower_range_value
                }
        }
}

COMMAND write_aifb_7_pv
{
        BLOCK aifb_7;
        INDEX 11;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_pv_upper_range_value,
                        aifb_7_pv_lower_range_value
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_out_scale
{
        BLOCK aifb_7;
        INDEX 12;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_out_upper_range_value,
                        aifb_7_out_lower_range_value,
                        aifb_7_out_unit,
                        aifb_7_out_decimal_point
                }
        }
}

COMMAND write_aifb_7_out_scale
{
        BLOCK aifb_7;
        INDEX 12;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_out_upper_range_value,
                        aifb_7_out_lower_range_value,
                        aifb_7_out_unit,
                        aifb_7_out_decimal_point
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_lin_type
{
        BLOCK aifb_7;
        INDEX 13;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_lin_type
                }
        }
}

COMMAND write_aifb_7_lin_type
{
        BLOCK aifb_7;
        INDEX 13;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_lin_type
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_channel
{
        BLOCK aifb_7;
        INDEX 14;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_channel
                }
        }
}

COMMAND write_aifb_7_channel
{
        BLOCK aifb_7;
        INDEX 14;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_channel
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_pv_ftime
{
        BLOCK aifb_7;
        INDEX 16;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_pv_ftime
                }
        }
}

COMMAND write_aifb_7_pv_ftime
{
        BLOCK aifb_7;
        INDEX 16;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_pv_ftime
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_FSafeType
{
        BLOCK aifb_7;
        INDEX 17;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_FSafeType
                }
        }
}

COMMAND write_aifb_7_FSafeType
{
        BLOCK aifb_7;
        INDEX 17;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_FSafeType
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_FSafeValue
{
        BLOCK aifb_7;
        INDEX 18;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_FSafeValue
                }
        }
}

COMMAND write_aifb_7_FSafeValue
{
        BLOCK aifb_7;
        INDEX 18;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_FSafeValue
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_alarm_hys
{
        BLOCK aifb_7;
        INDEX 19;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_alarm_hys
                }
        }
}


COMMAND write_aifb_7_alarm_hys
{
        BLOCK aifb_7;
        INDEX 19;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_alarm_hys
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_hi_hi_lim
{
        BLOCK aifb_7;
        INDEX 21;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_hi_hi_lim
                }
        }
}

COMMAND write_aifb_7_hi_hi_lim
{
        BLOCK aifb_7;
        INDEX 21;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_hi_hi_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_hi_lim
{
        BLOCK aifb_7;
        INDEX 23;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_hi_lim
                }
        }
}

COMMAND write_aifb_7_hi_lim
{
        BLOCK aifb_7;
        INDEX 23;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_hi_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_lo_lim
{
        BLOCK aifb_7;
        INDEX 25;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_lo_lim
                }
        }
}

COMMAND write_aifb_7_lo_lim
{
        BLOCK aifb_7;
        INDEX 25;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_lo_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_lo_lo_lim
{
        BLOCK aifb_7;
        INDEX 27;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_lo_lo_lim
                }
        }
}

COMMAND write_aifb_7_lo_lo_lim
{
        BLOCK aifb_7;
        INDEX 27;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_lo_lo_lim
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_hi_hi_alm
{
        BLOCK aifb_7;
        INDEX 30;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_hi_hi_alm_unacknowledged,
                        aifb_7_hi_hi_alm_state,
                        aifb_7_hi_hi_alm_time_stamp,
                        aifb_7_hi_hi_alm_subcode,
                        aifb_7_hi_hi_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_hi_alm
{
        BLOCK aifb_7;
        INDEX 31;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_hi_alm_unacknowledged,
                        aifb_7_hi_alm_state,
                        aifb_7_hi_alm_time_stamp,
                        aifb_7_hi_alm_subcode,
                        aifb_7_hi_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_lo_alm
{
        BLOCK aifb_7;
        INDEX 32;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_lo_alm_unacknowledged,
                        aifb_7_lo_alm_state,
                        aifb_7_lo_alm_time_stamp,
                        aifb_7_lo_alm_subcode,
                        aifb_7_lo_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_lo_lo_alm
{
        BLOCK aifb_7;
        INDEX 33;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_lo_lo_alm_unacknowledged,
                        aifb_7_lo_lo_alm_state,
                        aifb_7_lo_lo_alm_time_stamp,
                        aifb_7_lo_lo_alm_subcode,
                        aifb_7_lo_lo_alm_value
                }
        }
}
/*-------------------------------------------------------------------------*/
COMMAND read_aifb_7_simulate
{
        BLOCK aifb_7;
        INDEX 34;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_simulate_status,
                        aifb_7_simulate_value,
                        aifb_7_simulation_enabled
                }
        }
}

COMMAND write_aifb_7_simulate
{
        BLOCK aifb_7;
        INDEX 34;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_simulate_status,
                        aifb_7_simulate_value,
                        aifb_7_simulation_enabled
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/

COMMAND read_aifb_7_out_unit_text
{
        BLOCK aifb_7;
        INDEX 35;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        aifb_7_out_unit_text
                }
        }
}

COMMAND write_aifb_7_out_unit_text
{
        BLOCK aifb_7;
        INDEX 35;
        OPERATION WRITE ;
        TRANSACTION
        {
                REQUEST
                {
                        aifb_7_out_unit_text
                }
                REPLY
                {
                }
        }
}
/*-------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------*/
/* Function Block 7: AI                                                    */
/*-------------------------------------------------------------------------*/
UNIT AI_7_OUT_UNIT
{
        aifb_7_out_unit:

        aifb_7_out_value,                \
        aifb_7_out_upper_range_value,    \
        aifb_7_out_lower_range_value,    \
        aifb_7_hi_hi_lim,                \
        aifb_7_hi_lim,                   \
        aifb_7_lo_lim,                   \
        aifb_7_lo_lo_lim,                \
        aifb_7_hi_hi_alm_value,          \
        aifb_7_hi_alm_value,             \
        aifb_7_lo_alm_value,             \
        aifb_7_lo_lo_alm_value,          \
        aifb_7_FSafeValue
}
