/*-------------------------------------------------------------------------*/
/*      Copyright (c)      Softing AG 2008                                 */
/*      Product:           EDD for CiDRA SONAR                             */
/*                                                                         */
/*      Device:            CiDRA SONAR PA                                  */
/*                                                                         */
/*      Communication:     PROFIBUS PA                                     */
/*      Description:       General Definition                              */
/*      Dictionary:                                                        */
/*      Revision           1.00                                            */
/*      Date:                                                              */
/*      Author:                                                            */
/*-------------------------------------------------------------------------*/

#define BLOCK_MODE_AUTO       0x08
#define BLOCK_MODE_MAN        0x10
#define BLOCK_MODE_OUT_OF_SERVICE   0x80
#define BLOCK_MODE_RCAS       0x02
#define BLOCK_MODE_LO       0x20


#define CB_FAIL_SAFE    0x00010000    /* Bit  0 */
#define CB_REQ_LOC_OP   0x00020000    /* Bit  1 */
#define CB_LOCAL_OP   0x00040000    /* Bit  2 */
#define CB_OVERRIDE   0x00080000    /* Bit  3 */
#define CB_DISC_DIR   0x00100000    /* Bit  4 */
#define CB_TORQUE_D_OP    0x00200000    /* Bit  5 */
#define CB_TORQUE_D_CL    0x00400000    /* Bit  6 */
#define CB_TRAV_TIME    0x00800000    /* Bit  7 */
#define CB_ACT_OPEN   0x00000100    /* Bit  8 */
#define CB_ACT_CLOSE    0x00000200    /* Bit  9 */
#define CB_UPDATE_EVT   0x00000400    /* Bit 10 */
#define CB_SIMULATE   0x00000800    /* Bit 11 */
#define CB_DISTURBANCE    0x00001000    /* Bit 12 */
#define CB_CONTR_ERR    0x00002000    /* Bit 13 */
#define CB_CONTR_INACT    0x00004000    /* Bit 14 */
#define CB_SELFTEST   0x00008000    /* Bit 15 */
#define CB_TOT_VALVE_TRAV 0x00000001    /* Bit 16 */

#define STATUS_GENERAL           \
    { 0,  [bad_0]   }, \
    { 1,  [bad_1]   }, \
    { 2,  [bad_2]   }, \
    { 3,  [bad_3]   }, \
    { 4,  [bad_4]   }, \
    { 5,  [bad_5]   }, \
    { 6,  [bad_6]   }, \
    { 7,  [bad_7]   }, \
    { 8,  [bad_8]   }, \
    { 9,  [bad_9]   }, \
    { 10, [bad_10]  }, \
    { 11, [bad_11]  }, \
    { 12, [bad_12]  }, \
    { 13, [bad_13]  }, \
    { 14, [bad_14]  }, \
    { 15, [bad_15]  }, \
    { 16, [bad_16]  }, \
    { 17, [bad_17]  }, \
    { 18, [bad_18]  }, \
    { 19, [bad_19]  }, \
    { 20, [bad_20]  }, \
    { 21, [bad_21]  }, \
    { 22, [bad_22]  }, \
    { 23, [bad_23]  }, \
    { 24, [bad_24]  }, \
    { 25, [bad_25]  }, \
    { 26, [bad_26]  }, \
    { 27, [bad_27]  }, \
    { 28, [bad_28]  }, \
    { 29, [bad_29]  }, \
    { 30, [bad_30]  }, \
    { 31, [bad_31]  }, \
    { 64, [uncertain_64]  }, \
    { 65, [uncertain_65]  }, \
    { 66, [uncertain_66]  }, \
    { 67, [uncertain_67]  }, \
    { 68, [uncertain_68]  }, \
    { 69, [uncertain_69]  }, \
    { 70, [uncertain_70]  }, \
    { 71, [uncertain_71]  }, \
    { 72, [uncertain_72]  }, \
    { 73, [uncertain_73]  }, \
    { 74, [uncertain_74]  }, \
    { 75, [uncertain_75]  }, \
    { 76, [uncertain_76]  }, \
    { 77, [uncertain_77]  }, \
    { 78, [uncertain_78]  }, \
    { 79, [uncertain_79]  }, \
    { 80, [uncertain_80]  }, \
    { 81, [uncertain_81]  }, \
    { 82, [uncertain_82]  }, \
    { 83, [uncertain_83]  }, \
    { 84, [uncertain_84]  }, \
    { 85, [uncertain_85]  }, \
    { 86, [uncertain_86]  }, \
    { 87, [uncertain_87]  }, \
    { 88, [uncertain_88]  }, \
    { 89, [uncertain_89]  }, \
    { 90, [uncertain_90]  }, \
    { 91, [uncertain_91]  }, \
    { 92, [uncertain_92]  }, \
    { 93, [uncertain_93]  }, \
    { 94, [uncertain_94]  }, \
    { 95, [uncertain_95]  }, \
    { 96, [uncertain_96]  }, \
    { 97, [uncertain_97]  }, \
    { 98, [uncertain_98]  }, \
    { 99, [uncertain_99]  }, \
    {   100,  [uncertain_100] }, \
    {   101,  [uncertain_101] }, \
    {   102,  [uncertain_102] }, \
    {   103,  [uncertain_103] }, \
    { 128,  [good_128]  }, \
    { 129,  [good_129]  }, \
    { 130,  [good_130]  }, \
    { 131,  [good_131]  }, \
    { 132,  [good_132]  }, \
    { 133,  [good_133]  }, \
    { 134,  [good_134]  }, \
    { 135,  [good_135]  }, \
    { 136,  [good_136]  }, \
    { 137,  [good_137]  }, \
    { 138,  [good_138]  }, \
    { 139,  [good_139]  }, \
    { 140,  [good_140]  }, \
    { 141,  [good_141]  }, \
    { 142,  [good_142]  }, \
    { 143,  [good_143]  }, \
    { 144,  [good_144]  }, \
    { 145,  [good_145]  }, \
    { 146,  [good_146]  }, \
    { 147,  [good_147]  }, \
    { 148,  [good_148]  }, \
    { 149,  [good_149]  }, \
    { 150,  [good_150]  }, \
    { 151,  [good_151]  }, \
    { 152,  [good_152]  }, \
    { 153,  [good_153]  }, \
    { 154,  [good_154]  }, \
    { 155,  [good_155]  }, \
    { 160,  [good_160]  }, \
    { 161,  [good_161]  }, \
    { 162,  [good_162]  }, \
    { 163,  [good_163]  }, \
    { 164,  [good_164]  }, \
    { 165,  [good_165]  }, \
    { 166,  [good_166]  }, \
    { 167,  [good_167]  }, \
    { 192,  [good_192]  }, \
    { 193,  [good_193]  }, \
    { 194,  [good_194]  }, \
    { 195,  [good_195]  }, \
    { 196,  [good_196]  }, \
    { 197,  [good_197]  }, \
    { 198,  [good_198]  }, \
    { 199,  [good_199]  }, \
    { 200,  [good_200]  }, \
    { 201,  [good_201]  }, \
    { 202,  [good_202]  }, \
    { 203,  [good_203]  }, \
    { 204,  [good_204]  }, \
    { 205,  [good_205]  }, \
    { 206,  [good_206]  }, \
    { 207,  [good_207]  }, \
    { 208,  [good_208]  }, \
    { 209,  [good_209]  }, \
    { 210,  [good_210]  }, \
    { 211,  [good_211]  }, \
    { 212,  [good_212]  }, \
    { 213,  [good_213]  }, \
    { 214,  [good_214]  }, \
    { 215,  [good_215]  }, \
    { 216,  [good_216]  }, \
    { 217,  [good_217]  }, \
    { 218,  [good_218]  }, \
    { 219,  [good_219]  }, \
    { 220,  [good_220]  }, \
    { 221,  [good_221]  }, \
    { 222,  [good_222]  }, \
    { 223,  [good_223]  }, \
    { 224,  [good_224]  }, \
    { 225,  [good_225]  }, \
    { 226,  [good_226]  }, \
    { 227,  [good_227]  }

#define UNIT_LIST                   \
    { 1000, [unit_1000],  [unit_1000_help]  },  \
    { 1001, [unit_1001],  [unit_1001_help]  },  \
    { 1002, [unit_1002],  [unit_1002_help]  },  \
    { 1003, [unit_1003],  [unit_1003_help]  },  \
    { 1004, [unit_1004],  [unit_1004_help]  },  \
    { 1005, [unit_1005],  [unit_1005_help]  },  \
    { 1006, [unit_1006],  [unit_1006_help]  },  \
    { 1007, [unit_1007],  [unit_1007_help]  },  \
    { 1008, [unit_1008],  [unit_1008_help]  },  \
    { 1009, [unit_1009],  [unit_1009_help]  },  \
    { 1010, [unit_1010],  [unit_1010_help]  },  \
    { 1011, [unit_1011],  [unit_1011_help]  },  \
    { 1012, [unit_1012],  [unit_1012_help]  },  \
    { 1013, [unit_1013],  [unit_1013_help]  },  \
    { 1014, [unit_1014],  [unit_1014_help]  },  \
    { 1015, [unit_1015],  [unit_1015_help]  },  \
    { 1016, [unit_1016],  [unit_1016_help]  },  \
    { 1017, [unit_1017],  [unit_1017_help]  },  \
    { 1018, [unit_1018],  [unit_1018_help]  },  \
    { 1019, [unit_1019],  [unit_1019_help]  },  \
    { 1020, [unit_1020],  [unit_1020_help]  },  \
    { 1021, [unit_1021],  [unit_1021_help]  },  \
    { 1022, [unit_1022],  [unit_1022_help]  },  \
    { 1023, [unit_1023],  [unit_1023_help]  },  \
    { 1024, [unit_1024],  [unit_1024_help]  },  \
    { 1025, [unit_1025],  [unit_1025_help]  },  \
    { 1026, [unit_1026],  [unit_1026_help]  },  \
    { 1027, [unit_1027],  [unit_1027_help]  },  \
    { 1028, [unit_1028],  [unit_1028_help]  },  \
    { 1029, [unit_1029],  [unit_1029_help]  },  \
    { 1030, [unit_1030],  [unit_1030_help]  },  \
    { 1031, [unit_1031],  [unit_1031_help]  },  \
    { 1032, [unit_1032],  [unit_1032_help]  },  \
    { 1033, [unit_1033],  [unit_1033_help]  },  \
    { 1034, [unit_1034],  [unit_1034_help]  },  \
    { 1035, [unit_1035],  [unit_1035_help]  },  \
    { 1036, [unit_1036],  [unit_1036_help]  },  \
    { 1037, [unit_1037],  [unit_1037_help]  },  \
    { 1038, [unit_1038],  [unit_1038_help]  },  \
    { 1039, [unit_1039],  [unit_1039_help]  },  \
    { 1040, [unit_1040],  [unit_1040_help]  },  \
    { 1041, [unit_1041],  [unit_1041_help]  },  \
    { 1042, [unit_1042],  [unit_1042_help]  },  \
    { 1043, [unit_1043],  [unit_1043_help]  },  \
    { 1044, [unit_1044],  [unit_1044_help]  },  \
    { 1045, [unit_1045],  [unit_1045_help]  },  \
    { 1046, [unit_1046],  [unit_1046_help]  },  \
    { 1047, [unit_1047],  [unit_1047_help]  },  \
    { 1048, [unit_1048],  [unit_1048_help]  },  \
    { 1049, [unit_1049],  [unit_1049_help]  },  \
    { 1050, [unit_1050],  [unit_1050_help]  },  \
    { 1051, [unit_1051],  [unit_1051_help]  },  \
    { 1052, [unit_1052],  [unit_1052_help]  },  \
    { 1053, [unit_1053],  [unit_1053_help]  },  \
    { 1054, [unit_1054],  [unit_1054_help]  },  \
    { 1055, [unit_1055],  [unit_1055_help]  },  \
    { 1056, [unit_1056],  [unit_1056_help]  },  \
    { 1057, [unit_1057],  [unit_1057_help]  },  \
    { 1058, [unit_1058],  [unit_1058_help]  },  \
    { 1059, [unit_1059],  [unit_1059_help]  },  \
    { 1060, [unit_1060],  [unit_1060_help]  },  \
    { 1061, [unit_1061],  [unit_1061_help]  },  \
    { 1062, [unit_1062],  [unit_1062_help]  },  \
    { 1063, [unit_1063],  [unit_1063_help]  },  \
    { 1064, [unit_1064],  [unit_1064_help]  },  \
    { 1065, [unit_1065],  [unit_1065_help]  },  \
    { 1066, [unit_1066],  [unit_1066_help]  },  \
    { 1067, [unit_1067],  [unit_1067_help]  },  \
    { 1068, [unit_1068],  [unit_1068_help]  },  \
    { 1069, [unit_1069],  [unit_1069_help]  },  \
    { 1070, [unit_1070],  [unit_1070_help]  },  \
    { 1071, [unit_1071],  [unit_1071_help]  },  \
    { 1072, [unit_1072],  [unit_1072_help]  },  \
    { 1073, [unit_1073],  [unit_1073_help]  },  \
    { 1074, [unit_1074],  [unit_1074_help]  },  \
    { 1075, [unit_1075],  [unit_1075_help]  },  \
    { 1076, [unit_1076],  [unit_1076_help]  },  \
    { 1077, [unit_1077],  [unit_1077_help]  },  \
    { 1078, [unit_1078],  [unit_1078_help]  },  \
    { 1079, [unit_1079],  [unit_1079_help]  },  \
    { 1080, [unit_1080],  [unit_1080_help]  },  \
    { 1081, [unit_1081],  [unit_1081_help]  },  \
    { 1082, [unit_1082],  [unit_1082_help]  },  \
    { 1083, [unit_1083],  [unit_1083_help]  },  \
    { 1084, [unit_1084],  [unit_1084_help]  },  \
    { 1085, [unit_1085],  [unit_1085_help]  },  \
    { 1086, [unit_1086],  [unit_1086_help]  },  \
    { 1087, [unit_1087],  [unit_1087_help]  },  \
    { 1088, [unit_1088],  [unit_1088_help]  },  \
    { 1089, [unit_1089],  [unit_1089_help]  },  \
    { 1090, [unit_1090],  [unit_1090_help]  },  \
    { 1091, [unit_1091],  [unit_1091_help]  },  \
    { 1092, [unit_1092],  [unit_1092_help]  },  \
    { 1093, [unit_1093],  [unit_1093_help]  },  \
    { 1094, [unit_1094],  [unit_1094_help]  },  \
    { 1095, [unit_1095],  [unit_1095_help]  },  \
    { 1096, [unit_1096],  [unit_1096_help]  },  \
    { 1097, [unit_1097],  [unit_1097_help]  },  \
    { 1098, [unit_1098],  [unit_1098_help]  },  \
    { 1099, [unit_1099],  [unit_1099_help]  },  \
    { 1100, [unit_1100],  [unit_1100_help]  },  \
    { 1101, [unit_1101],  [unit_1101_help]  },  \
    { 1102, [unit_1102],  [unit_1102_help]  },  \
    { 1103, [unit_1103],  [unit_1103_help]  },  \
    { 1104, [unit_1104],  [unit_1104_help]  },  \
    { 1105, [unit_1105],  [unit_1105_help]  },  \
    { 1106, [unit_1106],  [unit_1106_help]  },  \
    { 1107, [unit_1107],  [unit_1107_help]  },  \
    { 1108, [unit_1108],  [unit_1108_help]  },  \
    { 1109, [unit_1109],  [unit_1109_help]  },  \
    { 1110, [unit_1110],  [unit_1110_help]  },  \
    { 1111, [unit_1111],  [unit_1111_help]  },  \
    { 1112, [unit_1112],  [unit_1112_help]  },  \
    { 1113, [unit_1113],  [unit_1113_help]  },  \
    { 1114, [unit_1114],  [unit_1114_help]  },  \
    { 1115, [unit_1115],  [unit_1115_help]  },  \
    { 1116, [unit_1116],  [unit_1116_help]  },  \
    { 1117, [unit_1117],  [unit_1117_help]  },  \
    { 1118, [unit_1118],  [unit_1118_help]  },  \
    { 1119, [unit_1119],  [unit_1119_help]  },  \
    { 1120, [unit_1120],  [unit_1120_help]  },  \
    { 1121, [unit_1121],  [unit_1121_help]  },  \
    { 1122, [unit_1122],  [unit_1122_help]  },  \
    { 1123, [unit_1123],  [unit_1123_help]  },  \
    { 1124, [unit_1124],  [unit_1124_help]  },  \
    { 1125, [unit_1125],  [unit_1125_help]  },  \
    { 1126, [unit_1126],  [unit_1126_help]  },  \
    { 1127, [unit_1127],  [unit_1127_help]  },  \
    { 1128, [unit_1128],  [unit_1128_help]  },  \
    { 1129, [unit_1129],  [unit_1129_help]  },  \
    { 1130, [unit_1130],  [unit_1130_help]  },  \
    { 1131, [unit_1131],  [unit_1131_help]  },  \
    { 1132, [unit_1132],  [unit_1132_help]  },  \
    { 1133, [unit_1133],  [unit_1133_help]  },  \
    { 1134, [unit_1134],  [unit_1134_help]  },  \
    { 1135, [unit_1135],  [unit_1135_help]  },  \
    { 1136, [unit_1136],  [unit_1136_help]  },  \
    { 1137, [unit_1137],  [unit_1137_help]  },  \
    { 1138, [unit_1138],  [unit_1138_help]  },  \
    { 1139, [unit_1139],  [unit_1139_help]  },  \
    { 1140, [unit_1140],  [unit_1140_help]  },  \
    { 1141, [unit_1141],  [unit_1141_help]  },  \
    { 1142, [unit_1142],  [unit_1142_help]  },  \
    { 1143, [unit_1143],  [unit_1143_help]  },  \
    { 1144, [unit_1144],  [unit_1144_help]  },  \
    { 1145, [unit_1145],  [unit_1145_help]  },  \
    { 1146, [unit_1146],  [unit_1146_help]  },  \
    { 1147, [unit_1147],  [unit_1147_help]  },  \
    { 1148, [unit_1148],  [unit_1148_help]  },  \
    { 1149, [unit_1149],  [unit_1149_help]  },  \
    { 1150, [unit_1150],  [unit_1150_help]  },  \
    { 1151, [unit_1151],  [unit_1151_help]  },  \
    { 1152, [unit_1152],  [unit_1152_help]  },  \
    { 1153, [unit_1153],  [unit_1153_help]  },  \
    { 1154, [unit_1154],  [unit_1154_help]  },  \
    { 1155, [unit_1155],  [unit_1155_help]  },  \
    { 1156, [unit_1156],  [unit_1156_help]  },  \
    { 1157, [unit_1157],  [unit_1157_help]  },  \
    { 1158, [unit_1158],  [unit_1158_help]  },  \
    { 1159, [unit_1159],  [unit_1159_help]  },  \
    { 1160, [unit_1160],  [unit_1160_help]  },  \
    { 1161, [unit_1161],  [unit_1161_help]  },  \
    { 1162, [unit_1162],  [unit_1162_help]  },  \
    { 1163, [unit_1163],  [unit_1163_help]  },  \
    { 1164, [unit_1164],  [unit_1164_help]  },  \
    { 1165, [unit_1165],  [unit_1165_help]  },  \
    { 1166, [unit_1166],  [unit_1166_help]  },  \
    { 1167, [unit_1167],  [unit_1167_help]  },  \
    { 1168, [unit_1168],  [unit_1168_help]  },  \
    { 1169, [unit_1169],  [unit_1169_help]  },  \
    { 1170, [unit_1170],  [unit_1170_help]  },  \
    { 1171, [unit_1171],  [unit_1171_help]  },  \
    { 1172, [unit_1172],  [unit_1172_help]  },  \
    { 1173, [unit_1173],  [unit_1173_help]  },  \
    { 1174, [unit_1174],  [unit_1174_help]  },  \
    { 1175, [unit_1175],  [unit_1175_help]  },  \
    { 1176, [unit_1176],  [unit_1176_help]  },  \
    { 1177, [unit_1177],  [unit_1177_help]  },  \
    { 1178, [unit_1178],  [unit_1178_help]  },  \
    { 1179, [unit_1179],  [unit_1179_help]  },  \
    { 1180, [unit_1180],  [unit_1180_help]  },  \
    { 1181, [unit_1181],  [unit_1181_help]  },  \
    { 1182, [unit_1182],  [unit_1182_help]  },  \
    { 1183, [unit_1183],  [unit_1183_help]  },  \
    { 1184, [unit_1184],  [unit_1184_help]  },  \
    { 1185, [unit_1185],  [unit_1185_help]  },  \
    { 1186, [unit_1186],  [unit_1186_help]  },  \
    { 1187, [unit_1187],  [unit_1187_help]  },  \
    { 1188, [unit_1188],  [unit_1188_help]  },  \
    { 1189, [unit_1189],  [unit_1189_help]  },  \
    { 1190, [unit_1190],  [unit_1190_help]  },  \
    { 1191, [unit_1191],  [unit_1191_help]  },  \
    { 1192, [unit_1192],  [unit_1192_help]  },  \
    { 1193, [unit_1193],  [unit_1193_help]  },  \
    { 1194, [unit_1194],  [unit_1194_help]  },  \
    { 1195, [unit_1195],  [unit_1195_help]  },  \
    { 1196, [unit_1196],  [unit_1196_help]  },  \
    { 1197, [unit_1197],  [unit_1197_help]  },  \
    { 1198, [unit_1198],  [unit_1198_help]  },  \
    { 1199, [unit_1199],  [unit_1199_help]  },  \
    { 1200, [unit_1200],  [unit_1200_help]  },  \
    { 1201, [unit_1201],  [unit_1201_help]  },  \
    { 1202, [unit_1202],  [unit_1202_help]  },  \
    { 1203, [unit_1203],  [unit_1203_help]  },  \
    { 1204, [unit_1204],  [unit_1204_help]  },  \
    { 1205, [unit_1205],  [unit_1205_help]  },  \
    { 1206, [unit_1206],  [unit_1206_help]  },  \
    { 1207, [unit_1207],  [unit_1207_help]  },  \
    { 1208, [unit_1208],  [unit_1208_help]  },  \
    { 1209, [unit_1209],  [unit_1209_help]  },  \
    { 1210, [unit_1210],  [unit_1210_help]  },  \
    { 1211, [unit_1211],  [unit_1211_help]  },  \
    { 1212, [unit_1212],  [unit_1212_help]  },  \
    { 1213, [unit_1213],  [unit_1213_help]  },  \
    { 1214, [unit_1214],  [unit_1214_help]  },  \
    { 1215, [unit_1215],  [unit_1215_help]  },  \
    { 1216, [unit_1216],  [unit_1216_help]  },  \
    { 1217, [unit_1217],  [unit_1217_help]  },  \
    { 1218, [unit_1218],  [unit_1218_help]  },  \
    { 1219, [unit_1219],  [unit_1219_help]  },  \
    { 1220, [unit_1220],  [unit_1220_help]  },  \
    { 1221, [unit_1221],  [unit_1221_help]  },  \
    { 1222, [unit_1222],  [unit_1222_help]  },  \
    { 1223, [unit_1223],  [unit_1223_help]  },  \
    { 1224, [unit_1224],  [unit_1224_help]  },  \
    { 1225, [unit_1225],  [unit_1225_help]  },  \
    { 1226, [unit_1226],  [unit_1226_help]  },  \
    { 1227, [unit_1227],  [unit_1227_help]  },  \
    { 1228, [unit_1228],  [unit_1228_help]  },  \
    { 1229, [unit_1229],  [unit_1229_help]  },  \
    { 1230, [unit_1230],  [unit_1230_help]  },  \
    { 1231, [unit_1231],  [unit_1231_help]  },  \
    { 1232, [unit_1232],  [unit_1232_help]  },  \
    { 1233, [unit_1233],  [unit_1233_help]  },  \
    { 1234, [unit_1234],  [unit_1234_help]  },  \
    { 1235, [unit_1235],  [unit_1235_help]  },  \
    { 1236, [unit_1236],  [unit_1236_help]  },  \
    { 1237, [unit_1237],  [unit_1237_help]  },  \
    { 1238, [unit_1238],  [unit_1238_help]  },  \
    { 1239, [unit_1239],  [unit_1239_help]  },  \
    { 1240, [unit_1240],  [unit_1240_help]  },  \
    { 1241, [unit_1241],  [unit_1241_help]  },  \
    { 1242, [unit_1242],  [unit_1242_help]  },  \
    { 1243, [unit_1243],  [unit_1243_help]  },  \
    { 1244, [unit_1244],  [unit_1244_help]  },  \
    { 1245, [unit_1245],  [unit_1245_help]  },  \
    { 1246, [unit_1246],  [unit_1246_help]  },  \
    { 1247, [unit_1247],  [unit_1247_help]  },  \
    { 1248, [unit_1248],  [unit_1248_help]  },  \
    { 1249, [unit_1249],  [unit_1249_help]  },  \
    { 1250, [unit_1250],  [unit_1250_help]  },  \
    { 1251, [unit_1251],  [unit_1251_help]  },  \
    { 1252, [unit_1252],  [unit_1252_help]  },  \
    { 1253, [unit_1253],  [unit_1253_help]  },  \
    { 1254, [unit_1254],  [unit_1254_help]  },  \
    { 1255, [unit_1255],  [unit_1255_help]  },  \
    { 1256, [unit_1256],  [unit_1256_help]  },  \
    { 1257, [unit_1257],  [unit_1257_help]  },  \
    { 1258, [unit_1258],  [unit_1258_help]  },  \
    { 1259, [unit_1259],  [unit_1259_help]  },  \
    { 1260, [unit_1260],  [unit_1260_help]  },  \
    { 1261, [unit_1261],  [unit_1261_help]  },  \
    { 1262, [unit_1262],  [unit_1262_help]  },  \
    { 1263, [unit_1263],  [unit_1263_help]  },  \
    { 1264, [unit_1264],  [unit_1264_help]  },  \
    { 1265, [unit_1265],  [unit_1265_help]  },  \
    { 1266, [unit_1266],  [unit_1266_help]  },  \
    { 1267, [unit_1267],  [unit_1267_help]  },  \
    { 1268, [unit_1268],  [unit_1268_help]  },  \
    { 1269, [unit_1269],  [unit_1269_help]  },  \
    { 1270, [unit_1270],  [unit_1270_help]  },  \
    { 1271, [unit_1271],  [unit_1271_help]  },  \
    { 1272, [unit_1272],  [unit_1272_help]  },  \
    { 1273, [unit_1273],  [unit_1273_help]  },  \
    { 1274, [unit_1274],  [unit_1274_help]  },  \
    { 1275, [unit_1275],  [unit_1275_help]  },  \
    { 1276, [unit_1276],  [unit_1276_help]  },  \
    { 1277, [unit_1277],  [unit_1277_help]  },  \
    { 1278, [unit_1278],  [unit_1278_help]  },  \
    { 1279, [unit_1279],  [unit_1279_help]  },  \
    { 1280, [unit_1280],  [unit_1280_help]  },  \
    { 1281, [unit_1281],  [unit_1281_help]  },  \
    { 1282, [unit_1282],  [unit_1282_help]  },  \
    { 1283, [unit_1283],  [unit_1283_help]  },  \
    { 1284, [unit_1284],  [unit_1284_help]  },  \
    { 1285, [unit_1285],  [unit_1285_help]  },  \
    { 1286, [unit_1286],  [unit_1286_help]  },  \
    { 1287, [unit_1287],  [unit_1287_help]  },  \
    { 1288, [unit_1288],  [unit_1288_help]  },  \
    { 1289, [unit_1289],  [unit_1289_help]  },  \
    { 1290, [unit_1290],  [unit_1290_help]  },  \
    { 1291, [unit_1291],  [unit_1291_help]  },  \
    { 1292, [unit_1292],  [unit_1292_help]  },  \
    { 1293, [unit_1293],  [unit_1293_help]  },  \
    { 1294, [unit_1294],  [unit_1294_help]  },  \
    { 1295, [unit_1295],  [unit_1295_help]  },  \
    { 1296, [unit_1296],  [unit_1296_help]  },  \
    { 1297, [unit_1297],  [unit_1297_help]  },  \
    { 1298, [unit_1298],  [unit_1298_help]  },  \
    { 1299, [unit_1299],  [unit_1299_help]  },  \
    { 1300, [unit_1300],  [unit_1300_help]  },  \
    { 1301, [unit_1301],  [unit_1301_help]  },  \
    { 1302, [unit_1302],  [unit_1302_help]  },  \
    { 1303, [unit_1303],  [unit_1303_help]  },  \
    { 1304, [unit_1304],  [unit_1304_help]  },  \
    { 1305, [unit_1305],  [unit_1305_help]  },  \
    { 1306, [unit_1306],  [unit_1306_help]  },  \
    { 1307, [unit_1307],  [unit_1307_help]  },  \
    { 1308, [unit_1308],  [unit_1308_help]  },  \
    { 1309, [unit_1309],  [unit_1309_help]  },  \
    { 1310, [unit_1310],  [unit_1310_help]  },  \
    { 1311, [unit_1311],  [unit_1311_help]  },  \
    { 1312, [unit_1312],  [unit_1312_help]  },  \
    { 1313, [unit_1313],  [unit_1313_help]  },  \
    { 1314, [unit_1314],  [unit_1314_help]  },  \
    { 1315, [unit_1315],  [unit_1315_help]  },  \
    { 1316, [unit_1316],  [unit_1316_help]  },  \
    { 1317, [unit_1317],  [unit_1317_help]  },  \
    { 1318, [unit_1318],  [unit_1318_help]  },  \
    { 1319, [unit_1319],  [unit_1319_help]  },  \
    { 1320, [unit_1320],  [unit_1320_help]  },  \
    { 1321, [unit_1321],  [unit_1321_help]  },  \
    { 1322, [unit_1322],  [unit_1322_help]  },  \
    { 1323, [unit_1323],  [unit_1323_help]  },  \
    { 1324, [unit_1324],  [unit_1324_help]  },  \
    { 1325, [unit_1325],  [unit_1325_help]  },  \
    { 1326, [unit_1326],  [unit_1326_help]  },  \
    { 1327, [unit_1327],  [unit_1327_help]  },  \
    { 1328, [unit_1328],  [unit_1328_help]  },  \
    { 1329, [unit_1329],  [unit_1329_help]  },  \
    { 1330, [unit_1330],  [unit_1330_help]  },  \
    { 1331, [unit_1331],  [unit_1331_help]  },  \
    { 1332, [unit_1332],  [unit_1332_help]  },  \
    { 1333, [unit_1333],  [unit_1333_help]  },  \
    { 1334, [unit_1334],  [unit_1334_help]  },  \
    { 1335, [unit_1335],  [unit_1335_help]  },  \
    { 1336, [unit_1336],  [unit_1336_help]  },  \
    { 1337, [unit_1337],  [unit_1337_help]  },  \
    { 1338, [unit_1338],  [unit_1338_help]  },  \
    { 1339, [unit_1339],  [unit_1339_help]  },  \
    { 1340, [unit_1340],  [unit_1340_help]  },  \
    { 1341, [unit_1341],  [unit_1341_help]  },  \
    { 1342, [unit_1342],  [unit_1342_help]  },  \
    { 1343, [unit_1343],  [unit_1343_help]  },  \
    { 1344, [unit_1344],  [unit_1344_help]  },  \
    { 1345, [unit_1345],  [unit_1345_help]  },  \
    { 1346, [unit_1346],  [unit_1346_help]  },  \
    { 1347, [unit_1347],  [unit_1347_help]  },  \
    { 1348, [unit_1348],  [unit_1348_help]  },  \
    { 1349, [unit_1349],  [unit_1349_help]  },  \
    { 1350, [unit_1350],  [unit_1350_help]  },  \
    { 1351, [unit_1351],  [unit_1351_help]  },  \
    { 1352, [unit_1352],  [unit_1352_help]  },  \
    { 1353, [unit_1353],  [unit_1353_help]  },  \
    { 1354, [unit_1354],  [unit_1354_help]  },  \
    { 1355, [unit_1355],  [unit_1355_help]  },  \
    { 1356, [unit_1356],  [unit_1356_help]  },  \
    { 1357, [unit_1357],  [unit_1357_help]  },  \
    { 1358, [unit_1358],  [unit_1358_help]  },  \
    { 1359, [unit_1359],  [unit_1359_help]  },  \
    { 1360, [unit_1360],  [unit_1360_help]  },  \
    { 1361, [unit_1361],  [unit_1361_help]  },  \
    { 1362, [unit_1362],  [unit_1362_help]  },  \
    { 1363, [unit_1363],  [unit_1363_help]  },  \
    { 1364, [unit_1364],  [unit_1364_help]  },  \
    { 1365, [unit_1365],  [unit_1365_help]  },  \
    { 1366, [unit_1366],  [unit_1366_help]  },  \
    { 1367, [unit_1367],  [unit_1367_help]  },  \
    { 1368, [unit_1368],  [unit_1368_help]  },  \
    { 1369, [unit_1369],  [unit_1369_help]  },  \
    { 1370, [unit_1370],  [unit_1370_help]  },  \
    { 1371, [unit_1371],  [unit_1371_help]  },  \
    { 1372, [unit_1372],  [unit_1372_help]  },  \
    { 1373, [unit_1373],  [unit_1373_help]  },  \
    { 1374, [unit_1374],  [unit_1374_help]  },  \
    { 1375, [unit_1375],  [unit_1375_help]  },  \
    { 1376, [unit_1376],  [unit_1376_help]  },  \
    { 1377, [unit_1377],  [unit_1377_help]  },  \
    { 1378, [unit_1378],  [unit_1378_help]  },  \
    { 1379, [unit_1379],  [unit_1379_help]  },  \
    { 1380, [unit_1380],  [unit_1380_help]  },  \
    { 1381, [unit_1381],  [unit_1381_help]  },  \
    { 1382, [unit_1382],  [unit_1382_help]  },  \
    { 1383, [unit_1383],  [unit_1383_help]  },  \
    { 1384, [unit_1384],  [unit_1384_help]  },  \
    { 1385, [unit_1385],  [unit_1385_help]  },  \
    { 1386, [unit_1386],  [unit_1386_help]  },  \
    { 1387, [unit_1387],  [unit_1387_help]  },  \
    { 1388, [unit_1388],  [unit_1388_help]  },  \
    { 1389, [unit_1389],  [unit_1389_help]  },  \
    { 1390, [unit_1390],  [unit_1390_help]  },  \
    { 1391, [unit_1391],  [unit_1391_help]  },  \
    { 1392, [unit_1392],  [unit_1392_help]  },  \
    { 1393, [unit_1393],  [unit_1393_help]  },  \
    { 1394, [unit_1394],  [unit_1394_help]  },  \
    { 1395, [unit_1395],  [unit_1395_help]  },  \
    { 1396, [unit_1396],  [unit_1396_help]  },  \
    { 1397, [unit_1397],  [unit_1397_help]  },  \
    { 1398, [unit_1398],  [unit_1398_help]  },  \
    { 1399, [unit_1399],  [unit_1399_help]  },  \
    { 1400, [unit_1400],  [unit_1400_help]  },  \
    { 1401, [unit_1401],  [unit_1401_help]  },  \
    { 1402, [unit_1402],  [unit_1402_help]  },  \
    { 1403, [unit_1403],  [unit_1403_help]  },  \
    { 1404, [unit_1404],  [unit_1404_help]  },  \
    { 1405, [unit_1405],  [unit_1405_help]  },  \
    { 1406, [unit_1406],  [unit_1406_help]  },  \
    { 1407, [unit_1407],  [unit_1407_help]  },  \
    { 1408, [unit_1408],  [unit_1408_help]  },  \
    { 1409, [unit_1409],  [unit_1409_help]  },  \
    { 1410, [unit_1410],  [unit_1410_help]  },  \
    { 1411, [unit_1411],  [unit_1411_help]  },  \
    { 1412, [unit_1412],  [unit_1412_help]  },  \
    { 1413, [unit_1413],  [unit_1413_help]  },  \
    { 1414, [unit_1414],  [unit_1414_help]  },  \
    { 1415, [unit_1415],  [unit_1415_help]  },  \
    { 1416, [unit_1416],  [unit_1416_help]  },  \
    { 1417, [unit_1417],  [unit_1417_help]  },  \
    { 1418, [unit_1418],  [unit_1418_help]  },  \
    { 1419, [unit_1419],  [unit_1419_help]  },  \
    { 1420, [unit_1420],  [unit_1420_help]  },  \
    { 1421, [unit_1421],  [unit_1421_help]  },  \
    { 1422, [unit_1422],  [unit_1422_help]  },  \
    { 1423, [unit_1423],  [unit_1423_help]  },  \
    { 1424, [unit_1424],  [unit_1424_help]  },  \
    { 1425, [unit_1425],  [unit_1425_help]  },  \
    { 1426, [unit_1426],  [unit_1426_help]  },  \
    { 1427, [unit_1427],  [unit_1427_help]  },  \
    { 1428, [unit_1428],  [unit_1428_help]  },  \
    { 1429, [unit_1429],  [unit_1429_help]  },  \
    { 1430, [unit_1430],  [unit_1430_help]  },  \
    { 1431, [unit_1431],  [unit_1431_help]  },  \
    { 1432, [unit_1432],  [unit_1432_help]  },  \
    { 1433, [unit_1433],  [unit_1433_help]  },  \
    { 1434, [unit_1434],  [unit_1434_help]  },  \
    { 1435, [unit_1435],  [unit_1435_help]  },  \
    { 1436, [unit_1436],  [unit_1436_help]  },  \
    { 1437, [unit_1437],  [unit_1437_help]  },  \
    { 1438, [unit_1438],  [unit_1438_help]  },  \
    { 1439, [unit_1439],  [unit_1439_help]  },  \
    { 1440, [unit_1440],  [unit_1440_help]  },  \
    { 1441, [unit_1441],  [unit_1441_help]  },  \
    { 1442, [unit_1442],  [unit_1442_help]  },  \
    { 1443, [unit_1443],  [unit_1443_help]  },  \
    { 1444, [unit_1444],  [unit_1444_help]  },  \
    { 1445, [unit_1445],  [unit_1445_help]  },  \
    { 1446, [unit_1446],  [unit_1446_help]  },  \
    { 1447, [unit_1447],  [unit_1447_help]  },  \
    { 1448, [unit_1448],  [unit_1448_help]  },  \
    { 1449, [unit_1449],  [unit_1449_help]  },  \
    { 1450, [unit_1450],  [unit_1450_help]  },  \
    { 1451, [unit_1451],  [unit_1451_help]  },  \
    { 1452, [unit_1452],  [unit_1452_help]  },  \
    { 1453, [unit_1453],  [unit_1453_help]  },  \
    { 1454, [unit_1454],  [unit_1454_help]  },  \
    { 1455, [unit_1455],  [unit_1455_help]  },  \
    { 1456, [unit_1456],  [unit_1456_help]  },  \
    { 1457, [unit_1457],  [unit_1457_help]  },  \
    { 1458, [unit_1458],  [unit_1458_help]  },  \
    { 1459, [unit_1459],  [unit_1459_help]  },  \
    { 1460, [unit_1460],  [unit_1460_help]  },  \
    { 1461, [unit_1461],  [unit_1461_help]  },  \
    { 1462, [unit_1462],  [unit_1462_help]  },  \
    { 1463, [unit_1463],  [unit_1463_help]  },  \
    { 1464, [unit_1464],  [unit_1464_help]  },  \
    { 1465, [unit_1465],  [unit_1465_help]  },  \
    { 1466, [unit_1466],  [unit_1466_help]  },  \
    { 1467, [unit_1467],  [unit_1467_help]  },  \
    { 1468, [unit_1468],  [unit_1468_help]  },  \
    { 1469, [unit_1469],  [unit_1469_help]  },  \
    { 1470, [unit_1470],  [unit_1470_help]  },  \
    { 1471, [unit_1471],  [unit_1471_help]  },  \
    { 1472, [unit_1472],  [unit_1472_help]  },  \
    { 1473, [unit_1473],  [unit_1473_help]  },  \
    { 1474, [unit_1474],  [unit_1474_help]  },  \
    { 1475, [unit_1475],  [unit_1475_help]  },  \
    { 1476, [unit_1476],  [unit_1476_help]  },  \
    { 1477, [unit_1477],  [unit_1477_help]  },  \
    { 1478, [unit_1478],  [unit_1478_help]  },  \
    { 1479, [unit_1479],  [unit_1479_help]  },  \
    { 1480, [unit_1480],  [unit_1480_help]  },  \
    { 1481, [unit_1481],  [unit_1481_help]  },  \
    { 1482, [unit_1482],  [unit_1482_help]  },  \
    { 1483, [unit_1483],  [unit_1483_help]  },  \
    { 1484, [unit_1484],  [unit_1484_help]  },  \
    { 1485, [unit_1485],  [unit_1485_help]  },  \
    { 1486, [unit_1486],  [unit_1486_help]  },  \
    { 1487, [unit_1487],  [unit_1487_help]  },  \
    { 1488, [unit_1488],  [unit_1488_help]  },  \
    { 1489, [unit_1489],  [unit_1489_help]  },  \
    { 1490, [unit_1490],  [unit_1490_help]  },  \
    { 1491, [unit_1491],  [unit_1491_help]  },  \
    { 1492, [unit_1492],  [unit_1492_help]  },  \
    { 1493, [unit_1493],  [unit_1493_help]  },  \
    { 1494, [unit_1494],  [unit_1494_help]  },  \
    { 1495, [unit_1495],  [unit_1495_help]  },  \
    { 1496, [unit_1496],  [unit_1496_help]  },  \
    { 1497, [unit_1497],  [unit_1497_help]  },  \
    { 1498, [unit_1498],  [unit_1498_help]  },  \
    { 1499, [unit_1499],  [unit_1499_help]  },  \
    { 1500, [unit_1500],  [unit_1500_help]  },  \
    { 1501, [unit_1501],  [unit_1501_help]  },  \
    { 1502, [unit_1502],  [unit_1502_help]  },  \
    { 1503, [unit_1503],  [unit_1503_help]  },  \
    { 1504, [unit_1504],  [unit_1504_help]  },  \
    { 1505, [unit_1505],  [unit_1505_help]  },  \
    { 1506, [unit_1506],  [unit_1506_help]  },  \
    { 1507, [unit_1507],  [unit_1507_help]  },  \
    { 1508, [unit_1508],  [unit_1508_help]  },  \
    { 1509, [unit_1509],  [unit_1509_help]  },  \
    { 1510, [unit_1510],  [unit_1510_help]  },  \
    { 1511, [unit_1511],  [unit_1511_help]  },  \
    { 1512, [unit_1512],  [unit_1512_help]  },  \
    { 1513, [unit_1513],  [unit_1513_help]  },  \
    { 1514, [unit_1514],  [unit_1514_help]  },  \
    { 1515, [unit_1515],  [unit_1515_help]  },  \
    { 1516, [unit_1516],  [unit_1516_help]  },  \
    { 1517, [unit_1517],  [unit_1517_help]  },  \
    { 1518, [unit_1518],  [unit_1518_help]  },  \
    { 1519, [unit_1519],  [unit_1519_help]  },  \
    { 1520, [unit_1520],  [unit_1520_help]  },  \
    { 1521, [unit_1521],  [unit_1521_help] },                \ /* UNIT_BAUME */
    { 1522, [unit_1522],  [unit_1522_help]  },                \ /* UNIT_INPM */
    { 32768, [unit_32768],  [unit_32768_help] },             \ /* Bar guage "
    { 32769, [unit_32769],  [unit_32769_help] },     \ /* Meter per Minute */
    { 32770, [unit_32770],  [unit_32770_help] },          \ /* Meter per Day */
    { 32771, [unit_32771],  [unit_32771_help] },          \ /* Feet per Day */
    { 32772, [unit_32772],  [unit_32772_help] }, \ /* Cubic Meter per User */
    { 32773, [unit_32773],  [unit_32773_help] },   \ /* Gallon per User */
    { 32774, [unit_32774],  [unit_32774_help] },      \ /* Liter per user */
    { 32775, [unit_32775],  [unit_32775_help] },      \ /* Meter per User */
    { 32776, [unit_32776],  [unit_32776_help] },      \ /* Feet per User */
    { 32777, [unit_32777],  [unit_32777_help] }, \ /* Imperial Gallon per User */
    { 32778, [unit_32778],  [unit_32778_help] }, \ /* Cubic Feet per User */
    { 32779, [unit_32779],  [unit_32779_help] },     \ /* User per Second */
    { 32780, [unit_32780],  [unit_32780_help] },     \ /* User per Minute */
    { 32781, [unit_32781],  [unit_32781_help] },       \ /* User per Hour */
    { 32782, [unit_32782],  [unit_32782_help] },        \ /* User per Day */
    { 32783, [unit_32783],  [unit_32783_help] },    \ /* User per User */
    { 32784, [unit_32784],  [unit_32784_help] }                     /* User */

#define   UNIT_PRESSURE             \
    { 1130, [unit_1130],  [unit_1130_help]  },  \
    { 1132, [unit_1132],  [unit_1132_help]  },  \
    { 1133, [unit_1133],  [unit_1133_help]  },  \
    { 1137, [unit_1137],  [unit_1137_help]  },  \
    { 1138, [unit_1138],  [unit_1138_help]  },  \
    { 1139, [unit_1139],  [unit_1139_help]  },  \
    { 1140, [unit_1140],  [unit_1140_help]  },  \
    { 1141, [unit_1141],  [unit_1141_help]  },  \
    { 1144, [unit_1144],  [unit_1144_help]  },  \
    { 1145, [unit_1145],  [unit_1145_help]  },  \
    { 1147, [unit_1147],  [unit_1147_help]  },  \
    { 1148, [unit_1148],  [unit_1148_help]  },  \
    { 1150, [unit_1150],  [unit_1150_help]  },  \
    { 1151, [unit_1151],  [unit_1151_help]  },  \
    { 1154, [unit_1154],  [unit_1154_help]  },  \
    { 1156, [unit_1156],  [unit_1156_help]  },  \
    { 1158, [unit_1158],  [unit_1158_help]  }

#define   UNIT_FLOW             \
    {1318, [unit_1318], [unit_1318_help]  },  \
    {1319, [unit_1319], [unit_1319_help]  },  \
    {1320, [unit_1320], [unit_1320_help]  },  \
    {1322, [unit_1322], [unit_1322_help]  },  \
    {1323, [unit_1323], [unit_1323_help]  },  \
    {1324, [unit_1324], [unit_1324_help]  },  \
    {1325, [unit_1325], [unit_1325_help]  },  \
    {1327, [unit_1327], [unit_1327_help]  },  \
    {1328, [unit_1328], [unit_1328_help]  },  \
    {1329, [unit_1329], [unit_1329_help]  },  \
    {1330, [unit_1330], [unit_1330_help]  },  \
    {1331, [unit_1331], [unit_1331_help]  },  \
    {1332, [unit_1332], [unit_1332_help]  },  \
    {1333, [unit_1333], [unit_1333_help]  },  \
    {1347, [unit_1347], [unit_1347_help]  },  \
    {1348, [unit_1348], [unit_1348_help]  },  \
    {1349, [unit_1349], [unit_1349_help]  },  \
    {1350, [unit_1350], [unit_1350_help]  },  \
    {1351, [unit_1351], [unit_1351_help]  },  \
    {1352, [unit_1352], [unit_1352_help]  },  \
    {1353, [unit_1353], [unit_1353_help]  },  \
    {1356, [unit_1356], [unit_1356_help]  },  \
    {1357, [unit_1357], [unit_1357_help]  },  \
    {1358, [unit_1358], [unit_1358_help]  },  \
    {1359, [unit_1359], [unit_1359_help]  },  \
    {1362, [unit_1362], [unit_1362_help]  },  \
    {1363, [unit_1363], [unit_1363_help]  },  \
    {1364, [unit_1364], [unit_1364_help]  },  \
    {1365, [unit_1365], [unit_1365_help]  },  \
    {1371, [unit_1371], [unit_1371_help]  },  \
    {1372, [unit_1372], [unit_1372_help]  },  \
    {1373, [unit_1373], [unit_1373_help]  },  \
    {1374, [unit_1374], [unit_1374_help]  }

#define   UNIT_DENS           \
    { 1097, [unit_1097],  [unit_1097_help]  },    \
    { 1100, [unit_1100],  [unit_1100_help]  },    \
    { 1107, [unit_1107],  [unit_1107_help]  },    \
    { 1111, "Baume" , "Baume"     },    \
    { 1426, [unit_1426],  [unit_1426_help]  },    \
    { 1343, [unit_1343],  [unit_1343_help]  },    \
    { 1346, [unit_1346],  [unit_1346_help]  },    \
    { 1521, "Degree GL",  "Degree G"    },    \
    { 1522, "INPM",   "INPM"      },    \
      { 1523, "Degree API", "Degree API"    },      \
    { 1524, "General Conc", "General Concentration Unit"  }

#define   UNIT_TEMP_TT            \
    { 1000, [unit_1000],  [unit_1000_help]  },    \
    { 1001, [unit_1001],  [unit_1001_help]  },    \
    { 1002, [unit_1002],  [unit_1002_help]  },  \
    { 1003, [unit_1003],  [unit_1003_help]  },  \
    { 1243, [unit_1243],  [unit_1243_help]  },  \
    { 1281, [unit_1281],  [unit_1281_help]  }

#define   UNIT_TEMP             \
    { 1000, [unit_1000],  [unit_1000_help]  },    \
    { 1001, [unit_1001],  [unit_1001_help]  },    \
    { 1002, [unit_1002],  [unit_1002_help]  }

#define UNIT_CIDRA_AO                   \
    { 1001, [unit_1001],  [unit_1001_help]  },  \ /* C */
    { 1002, [unit_1002],  [unit_1002_help]  },  \ /* F */
    { 1143, [unit_1143],  [unit_1143_help]  },  \ /* psig */
    { 1548, [unit_1548],  [unit_1548_help]  },  \ /* kPag */
    { 32768, "Barg", "Bar guage" },             \ /* barg */
    { 1342, [unit_1342],   [unit_1342_help]}

#define   Manufacturer_list       \
    {1, "Acromag"},       \
        {2, "Allen Bradley"},     \
        {3, "Ametek"},        \
        {4, "Analog Devices"},      \
        {5, "Elsag Bailey"},      \
        {6, "Beckman"},       \
        {7, "Bell Microsensor"},      \
        {8, "Bourns"},        \
        {9, "Bristol Babcock "},      \
        {10,  "Brooks Instrument"},     \
        {11,  "Chessell"},        \
        {12,  "Combustion Engineering"},    \
        {13,  "Daniel Industries"},     \
        {14,  "Delta"},       \
        {15,  "Dieterich Standard"},      \
        {16,  "Dohrmann"},        \
        {17,  "Endress & Hauser"},      \
        {18,  "Elsag Bailey"},      \
        {19,  "Fisher Controls"},     \
        {20,  "Foxboro"},       \
        {21,  "Fuji"},        \
    {22,  "Elsag Bailey"},      \
        {23,  "Honeywell"},       \
        {24,  "ITT Barton"},        \
        {25,  "Kay Ray/Sensall"},     \
        {26,  "Kent"},        \
        {27,  "Leeds & Northrup"},      \
        {28,  "Leslie"},        \
        {29,  "M-System Co."},      \
        {30,  "Measurex"},        \
        {31,  "Micro Motion"},      \
        {32,  "Moore Industries"},      \
        {33,  "Moore Products "},     \
        {34,  "Ohkura Electric"},     \
        {35,  "Paine"},       \
        {36,  "Rochester Instrument Systems"},  \
        {37,  "Ronan"},       \
        {38,  "Rosemount"},       \
        {39,  "Peek Measurement"},      \
        {40,  "Schlumberger"},      \
        {41,  "Sensall"},       \
        {42,  "Siemens"},       \
        {43,  "Camille Bauer"},     \
        {44,  "Toshiba"},       \
        {45,  "Transmation"},       \
        {46,  "Rosemount Analytic"},      \
        {47,  "Valmet"},        \
        {48,  "Valtek"},        \
        {49,  "Varec"},       \
        {50,  "Viatran"},       \
        {51,  "Weed"},        \
        {52,  "Westinghouse"},      \
        {53,  "Xomox"},       \
        {54,  "Yamatake"},        \
        {55,  "Yokogawa"},        \
        {56,  "Nuovo Pignone"},     \
        {57,  "Promac"},        \
        {58,  "Exac Corporation"},      \
        {59,  "KDG Mobrey"},        \
        {60,  "Arcom Control Systems"},   \
        {61,  "Princo"},        \
        {62,  "Smar"},        \
        {63,  "Foxboro Eckardt"},     \
        {64,  "Measurement Technology"},    \
        {65,  "Applied System Technologies"},   \
        {66,  "Samson"},        \
        {67,  "Sparling Instruments"},    \
        {68,  "Fireye"},        \
        {69,  "Krohne"},        \
        {70,  "Betz"},        \
        {71,  "Druck"},       \
        {72,  "SOR"},         \
        {73,  "Elcon Instruments"},     \
        {74,  "EMCO"},        \
        {75,  "Termiflex Corporation"},   \
        {76,  "VAF Instruments"},     \
        {77,  "Westlock Controls"},     \
        {78,  "Drexelbrook"},       \
        {79,  "Saab Tank Control"},     \
        {80,  "K-TEK"},       \
        {81,  "Flowdata"},        \
        {82,  "Draeger"},       \
        {83,  "Raytek"},        \
        {84,  "Meridian Instruments"},    \
        {85,  "BTG"},         \
        {86,  "Magnetrol"},       \
        {87,  "Neles Controls"},      \
        {88,  "Milltronics"},       \
        {89,  "HELIOS"},        \
        {90,  "Anderson Instrument Company"},   \
        {91,  "INOR"},        \
        {92,  "ROBERTSHAW"},        \
        {93,  "PEPPERL+FUCHS"},     \
        {94,  "ACCUTECH"},        \
        {95,  "Flow Measurement"},      \
        {96,  "KAMSTRUP"},        \
        {97,  "Knick"},       \
        {98,  "VEGA"},        \
        {99,  "MTS Systems Corp."},     \
        {100, "Oval"},        \
        {101, "Masoneilan-Dresser"},      \
        {102, "BESTA"},       \
        {103, "Ohmart"},        \
        {104, "Harold Beck and Sons"},    \
        {105, "rittmeyer instrumentation"},   \
        {106, "Rossel Messtechnik"},      \
        {107, "WIKA"},        \
        {108, "Bopp & Reuther Heinrichs"},    \
        {109, "PR Electronics"},      \
        {110, "Jordan Controls"},     \
        {111, "Valcom s.r.l."},     \
        {112, "US ELECTRIC MOTORS"},      \
        {113, "Apparatebau Hundsbach"},   \
        {118, "CiDRA Corporate Services"}, \
        {120, "Brkert"},       \
        {184, "SAIC"},        \
        {250, "not_used"},        \
        {251, "none"},        \
        {252, "unknown"},       \
        {253, "special"},       \
        {254,   "Softing"}
/*        {254,   "Reserved"}*/
