/*-------------------------------------------------------------------------*/
/*      Copyright (c)      Softing AG 2008                                 */
/*      Product:           EDD for CiDRA SONAR                             */
/*                                                                         */
/*      Device:            CiDRA SONAR     PA 2.20                         */
/*                                                                         */
/*      Communication:     PROFIBUS PA                                     */
/*      Description:       Definition for TB                               */
/*      Dictionary:                                                        */
/*      Revision           1.00                                            */
/*      Date:              2008/06/19                                      */
/*      Author:            SHR                                             */
/*-------------------------------------------------------------------------*/

BLOCK sonar_tb
{
        TYPE    TRANSDUCER;
        NUMBER  1;
}

/*-------------------------------------------------------------------------*/
/*    Transducer Block VARIABLE                                            */
/*-------------------------------------------------------------------------*/
/*    Standard Parameter (0-7)          (See PAprofile.pdf-3.3)            */
/*-------------------------------------------------------------------------*/
tb_blk_reserve              LIKE VARIABLE   phys_blk_reserve
{
}

VARIABLE tb_blk_object
{
        LABEL           [blk_block_object];
        HELP            [blk_block_object_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                {       3,      [blk_block_object_TRANSDUCER]   }
        }
        HANDLING        READ;
}

VARIABLE tb_blk_parent_class
{
        LABEL           [blk_parent_class];
        HELP            [trans_blk_parent_class_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                {       1,      [trans_blk_parent_class_PRESSURE]       }
        }
        HANDLING        READ;
}

VARIABLE tb_blk_class
{
        LABEL           [blk_class];
        HELP            [trans_blk_class_help];
        CLASS           CONTAINED;
        TYPE            ENUMERATED(1)
        {
                {       01,     [trans_pres_blk_class_DIFF]     }
        }
        HANDLING        READ;
}

tb_blk_dd_reference         LIKE VARIABLE   phys_blk_dd_reference
{
}

tb_blk_dd_rev               LIKE VARIABLE   phys_blk_dd_rev
{
}

tb_blk_profile              LIKE VARIABLE   phys_blk_profile
{
}

tb_blk_profile_rev          LIKE VARIABLE   phys_blk_profile_rev
{
}

tb_blk_execution_time       LIKE VARIABLE   phys_blk_execution_time
{
}

tb_blk_num_parameters       LIKE VARIABLE   phys_blk_num_parameters
{
}

tb_blk_index_view_1         LIKE VARIABLE   phys_blk_index_view_1
{
}

tb_blk_num_view_lists       LIKE VARIABLE   phys_blk_num_view_lists
{
}
/*-------------------------------------------------------------------------*/
tb_st_rev                   LIKE VARIABLE   phys_st_rev
{
        REDEFINE LABEL  "TB ST_REV";
}
/*-------------------------------------------------------------------------*/
tb_tag_desc                 LIKE VARIABLE   phys_tag_desc
{
        REDEFINE LABEL          "TB Tag";
}
/*-------------------------------------------------------------------------*/
tb_strategy                 LIKE VARIABLE   phys_strategy
{
}
/*-------------------------------------------------------------------------*/
tb_alert_key                LIKE VARIABLE   phys_alert_key
{
}
/*-------------------------------------------------------------------------*/
tb_target_mode              LIKE VARIABLE   phys_target_mode
{
        REDEFINE TYPE           ENUMERATED (1)
        {
                DEFAULT_VALUE   0x08;
                {       0x08,   [mode_AUTO]                             },
                {       0x80,   [mode_OUT_OF_SERVICE]                               }
        }
}
/*-------------------------------------------------------------------------*/
tb_actual_mode              LIKE VARIABLE   phys_actual_mode
{
}

tb_permitted_mode           LIKE VARIABLE   phys_permitted_mode
{
}

tb_normal_mode              LIKE VARIABLE   phys_normal_mode
{
}
/*-------------------------------------------------------------------------*/
tb_current_state_alarm_sum          LIKE VARIABLE   phys_current_state_alarm_sum
{
}

tb_unacknowledged_state_alarm_sum   LIKE VARIABLE   phys_unacknowledged_state_alarm_sum
{
}

tb_unreported_state_alarm_sum       LIKE VARIABLE   phys_unreported_state_alarm_sum
{
}

tb_disabled_state_alarm_sum         LIKE VARIABLE   phys_disabled_state_alarm_sum
{
}

/*-------------------------------------------------------------------------*/
/*    TB -- Manufacturer specific Parameters (13-56)                       */
/*-------------------------------------------------------------------------*/

/*--------------------------------------------------------- index 13 ------*/

VARIABLE    tb_control_write_control
{
    LABEL           "|en|Write Control" ;
    HELP            "|en|Controls ability to write and commit changes to transmitter configuration." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED(1)
      {
           {0,"Inactive","Write Protect is turned on"},
           {1,"Enter Write Mode","Write Protect is turned off"},
           {2,"Commit Changes","Save Changes"}
      }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_control_reset_totalizer
{
    LABEL           "|en|Reset Totalizer" ;
    HELP            "|en|Resets all totalizers to zero." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED(1)
      {
           {0,"RUN"},
           {1,"RESET"}
      }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_control_clear_alarm
{
    LABEL           "|en|Clear Alarm" ;
    HELP            "|en|Clear any existing alarms." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED(1)
      {
           {0,"RUN"},
           {1,"CLEAR"}

      }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_control_clear_data_history
{
    LABEL           "|en|Clear Data History" ;
    HELP            "|en|Clears the data history memory." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED(1)
      {
           {0,"RUN"},
           {1,"CLEAR"}

      }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}


/*------------------------------------------------------- index 14 -----*/


VARIABLE    tb_device_info_transmitter_sn
{
    LABEL           "|en|Transmitter Serial Number" ;
    HELP            "|en|Transmitter Serial Number" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


VARIABLE    tb_device_info_model_number
{
    LABEL           "|en|Transmitter Model Number" ;
    HELP            "|en|Transmitter Model Number" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


VARIABLE    tb_device_info_software_revision
{
    LABEL           "|en|Transmitter Software Revision" ;
    HELP            "|en|Transmitter Software Revision" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


VARIABLE    tb_device_info_alchemy_software_revision
{
    LABEL           "|en|Alchemy Software Revision" ;
    HELP            "|en|Alchemy Software Revision" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


VARIABLE    tb_device_info_sensorhead_sn
{
    LABEL           "|en|Sensorhead Serial Number" ;
    HELP            "|en|Sensorhead Serial Number" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


VARIABLE    tb_device_info_preamp_software_revision
{
    LABEL           "|en|Preamp Software Revision" ;
    HELP            "|en|Preamp Software Revision" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_device_info_preamp_serial_number
{
    LABEL           "|en|Preamp Serial Number" ;
    HELP            "|en|Preamp Serial Number" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}


/*--------------------------------------------------------- index 15 ------*/

VARIABLE    tb_pipe_info_pipe_diameter_input_mode
{
    LABEL           "|en|Pipe Diameter Input Mode" ;
    HELP            "|en|Selects method used to set pipe dimensions." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
      {0,"Inside Diameter"},
      {1,"Not Used"},
      {2,"Size / Schedule"},
      {3,"Outside Diameter / Wall Thickness"}

    }

    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_pipe_diameter_units
{
    LABEL           "|en|Pipe ID Units" ;
    HELP            "|en|Selects units used for 'Pipe ID'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
      { 1019, [unit_1019], [unit_1019_help] }, /* INCHES*/
      { 1013, [unit_1013], [unit_1013_help] }  /* MM*/
    }
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_pipe_id
{
    LABEL           "|en|Pipe ID" ;
    HELP            "|en|Pipe Inside Diameter Measurement.  Will only be applied if 'Inside Diameter' is selected for 'Pipe Diameter Input Mode'." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ& WRITE  ;
}


VARIABLE    tb_pipe_info_pipe_od
{
    LABEL           "|en|Pipe OD" ;
    HELP            "|en|Pipe Outside Diameter Measurement.  Will only be applied if 'Outside Diameter / Wall Thickness' is selected for 'Pipe Diameter Input Mode'." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_pipe_info_pipe_od_wall_units
{
    LABEL           "|en|Pipe OD / Wall Units" ;
    HELP            "|en|Selects units used for 'Pipe OD' and 'Pipe Wall Thickness'.  Will only be applied if 'Outside Diameter / Wall Thickness' is selected for 'Pipe Diameter Input Mode'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
            { 1019, [unit_1019], [unit_1019_help] }, /* INCHES*/
            { 1013, [unit_1013], [unit_1013_help] }  /* MM*/
    }
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_pipe_wall_thickness
{
    LABEL           "|en|Pipe Wall Thickness" ;
    HELP            "|en|Pipe wall thickness measurement in selected units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE  ;
}

VARIABLE    tb_pipe_info_pipe_size
{
    LABEL           "|en|Pipe Size" ;
    HELP            "|en|Selects pipe size.  Will only be applied if 'Size / Schedule' is selected for 'Pipe Diameter Input Mode'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
      {0,"2"},
      {1,"2.5"},
      {2,"3"},
      {3,"3.5"},
      {4,"4"},
      {5,"5"},
      {6,"6"},
      {7,"8"},
      {8,"10"},
      {9,"12"},
      {10,"14"},
      {11,"16"},
      {12,"18"},
      {13,"20"},
      {14,"22"},
      {15,"24"},
      {16,"26"},
      {17,"28"},
      {18,"30"},
      {19,"32"},
      {20,"34"},
      {21,"36"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_pipe_schedule
{
    LABEL           "|en|Pipe Schedule" ;
    HELP            "|en|Selects pipe schedule.  Will only be applied if 'Size / Schedule' is selected for 'Pipe Diameter Input Mode'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
      {0,"5S"},
      {1,"10"},
      {2,"10S"},
      {3,"20"},
      {4,"30"},
      {5,"40"},
      {6,"40S"},
      {7,"60"},
      {8,"80"},
      {9,"80S"},
      {10,"STD"},
      {11,"XS"}

    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_sos_pipe_wall_thickness_units
{
    LABEL           "|en|SOS Pipe Wall Thickness Units" ;
    HELP            "|en|Selects units used for 'SOS Pipe Wall Thickness'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
              { 1019, [unit_1019], [unit_1019_help] }, /* INCHES*/
              { 1013, [unit_1013], [unit_1013_help] }  /* MM*/
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_sos_pipe_wall_thickness
{
    LABEL           "|en|SOS Pipe Wall Thickness" ;
    HELP            "|en|SOS pipe wall thickness measurement in units selected by 'SOS Pipe Wall Thickness Units'." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ& WRITE  ;
}

VARIABLE    tb_pipe_info_sos_pipe_modulus_selection
{
    LABEL           "|en|SOS Pipe Modulus Selection" ;
    HELP            "|en|Selects either a pre-defined modulus, or the option to enter a custom value.  Select 'Custom' to enter a value in 'SOS Pipe Modulus'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
      {0,"SS"},
      {1,"Steel"},
      {2,"PVC"},
      {3,"Custom"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_pipe_info_sos_pipe_modulus
{
    LABEL           "|en|SOS Pipe Modulus" ;
    HELP            "|en|SOS pipe modulus value." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1133] ;   /* kPa kilopascal */
    HANDLING        READ& WRITE  ;
}

/*--------------------------------------------------------- index 16 ------*/


VARIABLE    tb_fluid_properties_flow_viscosity
{
    LABEL           "|en|Flow Viscosity" ;
    HELP            "|en|Viscosity in Pascal seconds of the fluid at the operating conditions.  Used for Reynolds correction." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1159] ;   /* Pa-s pascal second */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_fluid_properties_sos_gas_constant_selection
{
    LABEL           "|en|SOS Gas Constant Selection" ;
    HELP            "|en|Selects use of pre-defined SOS Gas Constant or a custom value, enterd in 'SOS Gas Constant'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
  {
    {0,"Air Const"},
    {1,"Custom"}

  }
    HANDLING        READ & WRITE;
}

VARIABLE    tb_fluid_properties_sos_specfic_gravity_selection
{
    LABEL           "|en|SOS Specfic Gravity Selection" ;
    HELP            "|en|Selects use of pre-defined SOS Specific Gravity or a custom value, entered in 'SOS Specfic Gravity'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
  {
    {0,"Water Const"},
    {1,"Custom"}

  }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_fluid_properties_sos_liquid_sound_speed_selection
{
    LABEL           "|en|SOS Liquid Sound Speed Selection" ;
    HELP            "|en|Selects use of pre-defined SOS Liquid Sound Speed or a custom value, enterd in 'SOS Liquid Sound Speed'" ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
  {
    {0,"Water Const"},
    {1,"Custom"}

  }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_fluid_properties_sos_gas_constant
{
    LABEL           "|en|SOS Gas Constant" ;
    HELP            "|en|Gas constant value used in GVF calculation." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1204] ;   /* J/(kg-K) Joules per kilogram kelvin */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_fluid_properties_sos_specific_gravity
{
    LABEL           "|en|SOS Specific Gravity" ;
    HELP            "|en|This parameter (internally multiplied by 1000 kg/m^3) is used to set the 'SOS Liquid Density'.  For example, Specfic Gravity = 1.1 equates to density of 1.1 * 1000 kg/m^3" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_fluid_properties_sos_liquid_sound_speed
{
    LABEL           "|en|SOS Liquid Sound Speed" ;
    HELP            "|en|Pure phase liquid SOS for process fluid in ft/sec.  Used for GVF calculation.  Default setting is for water, and is close enough for most fluid/gas applications." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1067] ;   /* ft/s feet per second */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_fluid_properties_sos_polytropic_exponent
{
    LABEL           "|en|SOS Polytropic Exponent" ;
    HELP            "|en|Polytropic exponent in GVF calculations." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_fluid_properties_sos_liquid_density
{
    LABEL           "|en|SOS Liquid Density" ;
    HELP            "|en|Calculated from 'SOS Specfic Gravity'." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

/*--------------------------------------------------------- index 17 ------*/

VARIABLE    tb_environment_sos_temperature_input_selection
{
    LABEL           "|en|SOS Temperature Input Selection" ;
    HELP            "|en|Selects the source of the temperature used in GVF calculations.  'Fixed' uses 'SOS Process Temperature', 'Sensor 1' uses the 4-20mA input channel 1, 'Sensor 2' uses 4-20mA input channel 2, Protocol uses values written to Fieldbus AO Channel 11." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        {0,"Fixed"},
        {1,"Sensor 1"},
        {2,"Sensor 2"},
        {3,"Protocol"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_environment_sos_pressure_input_selection
{
    LABEL           "|en|SOS Pressure Input Selection" ;
    HELP            "|en|Selects the source of the pressure used in GVF calculations.  'Fixed' uses 'SOS Process Pressure', 'Sensor 1' uses the 4-20mA input channel 1, 'Sensor 2' uses 4-20mA input channel 2, Protocol uses values written to Fieldbus AO Channel 10." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        {0,"Fixed"},
        {1,"Sensor 1"},
        {2,"Sensor 2"},
        {3,"Protocol"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_environment_sos_temperature_units
{
    LABEL           "|en|SOS Temperature Units" ;
    HELP            "|en|Selects units used for input of 'SOS Process Temperature'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {

                { 1001, [unit_1001], [unit_1001_help] },       /* ^C  */
                { 1002, [unit_1002], [unit_1002_help] }        /* ^F  */

    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_environment_sos_pressure_units
{
    LABEL           "|en|SOS Pressure Units" ;
    HELP            "|en|Selects units used for input of 'SOS Process Pressure'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {

              { 1143, [unit_1143], [unit_1143_help] },    /* PSIg */
              { 1548, [unit_1548], [unit_1548_help] },    /* kPSAg*/
              /*{ 1137, [unit_1137], [unit_1137_help] }*/     /* BAR  */
              { 32768, "Barg", "bar guage" }     /* BARG  */

    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_environment_sos_process_temperature
{
    LABEL           "|en|SOS Process Temperature" ;
    HELP            "|en|Constant temperature for GVF calculations when 'Fixed' is selected for 'SOS Temperature Input Selection'.  In configured units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_environment_sos_process_pressure
{
    LABEL           "|en|SOS Process Pressure" ;
    HELP            "|en|Constant pressure for GVF calculations when 'Fixed' is selected for 'SOS Pressure Input Selection'.  In configured units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_environment_altitude_units
{
    LABEL           "|en|Altitude Units" ;
    HELP            "|en|Selects units used for entry of 'Altitude'." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
              { 1018, [unit_1018], [unit_1018_help] },     /* FEET */
              { 1010, [unit_1010], [unit_1010_help] }      /* METERS*/
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_environment_altitude
{
    LABEL           "|en|Altitude" ;
    HELP            "|en|Altitude correction applied to SOS pressure.   In configured units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}


/*--------------------------------------------------------- index 18 ------*/


VARIABLE    tb_display_flow_volume_units
{
    LABEL           "|en|Flow Volume Units" ;
    HELP            "|en|Selects units used to display and log flow volume." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
             { 1034, [unit_1034], [unit_1034_help] }, /* CUBIC METERS */
             { 1038, [unit_1038], [unit_1038_help] }, /* LETERS*/
             { 1048, [unit_1048], [unit_1048_help] },      /* US GALLON*/
             { 1010, [unit_1010], [unit_1010_help] },      /* METERS*/
             { 1018, [unit_1018], [unit_1018_help] },      /* FEET*/
             { 1049, [unit_1049], [unit_1049_help] }, /*IMPERIAL GALLON */
             { 1043, [unit_1043], [unit_1043_help] }, /*CUBIC FEET */
             { 32784, "user", "User" }  /* USER */
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_flow_time_units
{
    LABEL           "|en|Flow Time Units" ;
    HELP            "|en|Selects units used to display and log flow time." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
            { 1060, [unit_1060], [unit_1060_help] }, /* DAY */
            { 1059, [unit_1059], [unit_1059_help] }, /* HOUR */
            { 1058, [unit_1058], [unit_1058_help] }, /* MINUTE */
            { 1054, [unit_1054], [unit_1054_help] }, /* SECOND */
            { 32784, "user", "User" }  /* USER */
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_flow_low_cutoff_pct
{
    LABEL           "|en|Flow Low Cutoff Percentage" ;
    HELP            "|en|Low flow cutoff as a % of flow measurement range (defined by 'Flow Min' and 'Flow Max').  Will not display or output flow reading if flow rate is below this setting." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1342] ;   /* % percent */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_display_flow_high_cutoff_pct
{
    LABEL           "|en|Flow High Cutoff Percentage" ;
    HELP            "|en|High flow cutoff as a % of flow measurement range (defined by Flow Min and Flow Max).  Will not display or output flow reading if flow rate is above this setting." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1342] ;   /* % percent */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_display_flow_custom_base_volume_unit
{
    LABEL           "|en|Flow Custom Base Volume Unit" ;
    HELP            "|en|Selects volume units used in calculation of a custom unit." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
             { 1034, [unit_1034], [unit_1034_help] }, /* CUBIC METERS */
             { 1038, [unit_1038], [unit_1038_help] }, /* LETERS*/
             { 1048, [unit_1048], [unit_1048_help] },      /* US GALLON*/
             { 1010, [unit_1010], [unit_1010_help] },      /* METERS*/
             { 1018, [unit_1018], [unit_1018_help] },      /* FEET*/
             { 1049, [unit_1049], [unit_1049_help] }, /*IMPERIAL GALLON */
             { 1043, [unit_1043], [unit_1043_help] }  /*CUBIC FEET */
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_flow_custom_base_time_unit
{
    LABEL           "|en|Flow Custom Base Time Unit" ;
    HELP            "|en|Selects time units used in calculation of a custom unit." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {

            { 1060, [unit_1060], [unit_1060_help] }, /* DAY */
            { 1059, [unit_1059], [unit_1059_help] }, /* HOUR */
            { 1058, [unit_1058], [unit_1058_help] }, /* MINUTE */
            { 1054, [unit_1054], [unit_1054_help] }  /* SECOND */

    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_flow_custom_volume_unit_label
{
    LABEL           "|en|Flow Custom Volume Unit Label" ;
    HELP            "|en|Three character string used for display and logging of a custom flow volume unit." ;
    CLASS           CONTAINED ;
    TYPE            ASCII (3) ; /*OCTET (3) ;*/
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_flow_custom_time_unit_label
{
    LABEL           "|en|Flow Custom Time Unit Label" ;
    HELP            "|en|Two character string used for display and logging of a custom flow time unit." ;
    CLASS           CONTAINED ;
    TYPE            ASCII (2) ; /*OCTET (2) ;*/
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_flow_custom_volume_unit_multiplier
{
    LABEL           "|en|Flow Custom Volume Unit Multiplier" ;
    HELP            "|en|Scale applied to 'Flow Custom Base Volume Unit' for calculation of a custom volume unit." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_display_flow_custom_time_unit_multiplier
{
    LABEL           "|en|Flow Custom Time Unit Multiplier" ;
    HELP            "|en|Scale applied to 'Flow Custom Base Time Unit' for calculation of a custom time unit." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_display_flow_quality_delta
{
    LABEL           "|en|Flow Quality Delta" ;
    HELP            "|en|Delta change from minimum quality at minimum flow (MIN_QUALITY) to minimum quality at max flow (MIN_QUALITY+ 'Flow Quality Delta').  Zero (0) indicates no variable quality." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_display_gvf_decimal_places
{
    LABEL           "|en|GVF Decimal Places" ;
    HELP            "|en|Sets the number of decimal places used to display GVF on the front panel." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_sos_measurement_units
{
    LABEL           "|en|SOS Measurement Units" ;
    HELP            "|en|Selects units used for display and log of SOS." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
        { 1018, [unit_1018], [unit_1018_help] }, /* FEET */
        { 1010, [unit_1010], [unit_1010_help] }      /* METERS*/
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_display_sos_quality_delta
{
    LABEL           "|en|SOS Quality Delta" ;
    HELP            "|en|Delta change from SOS minimum quality at minimum SOS (SOS_MIN_QUALITY) to minimum quality at max SOS (SOS_MIN_QUALITY+ 'SOS Quality Delta').  Zero (0) indicates no variable quality." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 19 ------*/

VARIABLE    tb_system_system_config_mode
{
    LABEL           "|en|System Config Mode" ;
    HELP            "|en|Sets operating mode of the transmitter.  VF Mode = 0, SOS Mode = 1, Both Mode = 2." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_system_update_rate
{
    LABEL           "|en|Update Rate" ;
    HELP            "|en|Sets transmitter update rate.  Defines time units in number of blocks.  This parameter will set the update rate in seconds (nominally).  Actual update rate (in seconds) can be calculated by taking (BLOCK_SIZE / SAMPLE_FREQ) * UPDATE_RATE (VF mode) or (BLOCK_SIZE / SOS_SAMPLE_FREQ) * UPDATE_RATE (SOS mode)." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE;
}

VARIABLE    tb_system_sensors_in_use
{
    LABEL           "|en|Sensors In Use" ;
    HELP            "|en|Sets number of sensors.  Always leave set to 8.  Do not use this parameter to disable a sensor, use NUM_SENSORS_USED parameter to set which sensors to use in calculations." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_system_transmitter_gain
{
    LABEL           "|en|Transmitter Gain" ;
    HELP            "|en|Set gain stage before A/D converter in transmitter.  This is NOT sensor head gain (preamp gain).  It is normally not a parameter which is modified.  Use with caution.  Choose one of the following values: 1.0, 5.0, 20.0, 24.0, 48.0, 52.0, 67.0, 71.0, 202.0, 207.0, 221.0, 225.0, 250.0, 254.0, 269.0, 272.0" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_system_spl_threshold
{
    LABEL           "|en|SPL Threshold" ;
    HELP            "|en|This value is the threshold that the Average SPL must break in order for any SOS or VF calculations to be performed. A quality of -2 is reported if this threshold is not met.  Set this value to 0 to disable SPL." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_system_write_protect
{
    LABEL           "|en|Write Protect" ;
    HELP            "|en|Enable or disable modifications to the transmitters FLASH memory.  When modifying this, change only this for proper operation." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
      { 0, "DISABLED"    },
      { 1, "ENABLED"  }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_system_idle_timeout
{
    LABEL           "|en|Idle Timeout" ;
    HELP            "|en|If the transmitter is in idle mode, and no communications are detected on a serial or Ethernet port for this time period, transmitter will automatically go to run mode. A setting of 0 disables this." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (2) ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE;
}

VARIABLE    tb_system_ethernet_idle_timeout
{
    LABEL           "|en|Ethernet Idle Timeout" ;
    HELP            "|en|If no communications are detected on the Ethernet port for this time period, transmitter will automatically close the connection. A setting of 0 disables this timeout." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (2) ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE;
}

VARIABLE    tb_system_out_of_range_mode
{
    LABEL   "|en|Out of Range Mode" ;
    HELP    [blank] ;
    CLASS   CONTAINED ;
    TYPE    ENUMERATED (1)
    {
        { 0, "Do not rail"  },
        { 1, "Rail"     }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING    READ & WRITE ;
}

/*--------------------------------------------------------- index 20 ------*/

VARIABLE    tb_system_dynamic_spl_average
{
    LABEL           "|en|SPL Average" ;
    HELP            "|en|The average SPL measurement from all active sensors." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_system_dynamic_spl_std_dev
{
    LABEL           "|en|SPL Standard Deviation" ;
    HELP            "|en|The standard deviation of the SPL measurements from all active sensors." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

/*--------------------------------------------------------- index 21 ------*/

VARIABLE    tb_preamp_gain
{
    LABEL           "|en|Preamp Gain" ;
    HELP            "|en|Gain selection for the preamp.  Set a value 0 thru 3 to choose gain listed by 'Preamp Gain 0', 'Preamp Gain 1', 'Preamp Gain 2' or 'Preamp Gain 3'" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_preamp_auto_gain_mode
{
    LABEL           "|en|Preamp Auto Gain Mode" ;
    HELP            "|en|Preamp Auto Gain Mode" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_preamp_charge_gain
{
    LABEL           "|en|Preamp Charge Gain" ;
    HELP            "|en|Charge gain as read from the preamp." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_preamp_gain_0
{
    LABEL           "|en|Preamp Gain 0" ;
    HELP            "|en|Preamp Gain 0 as read from the preamp." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_preamp_gain_1
{
    LABEL           "|en|Preamp Gain 1" ;
    HELP            "|en|Preamp Gain 1 as read from the preamp." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_preamp_gain_2
{
    LABEL           "|en|Preamp Gain 2" ;
    HELP            "|en|Preamp Gain 2 as read from the preamp." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_preamp_gain_3
{
    LABEL           "|en|Preamp Gain 3" ;
    HELP            "|en|Preamp Gain 3 as read from the preamp." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

/*--------------------------------------------------------- index 22 ------*/

VARIABLE    tb_flow_algorithm_flow_sample_freq
{
    LABEL           "|en|Flow Sample Freq" ;
    HELP            "|en|Set A/D sample frequency in samples per second.  Enter one of the following: 3906.25, 2055.921." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1077] ;  /* Hz hertz */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_channel_skew
{
    LABEL           "|en|Flow Channel Skew" ;
    HELP            "|en|Flow Channel Skew" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_freq_min
{
    LABEL           "|en|Flow Freq Min" ;
    HELP            "|en|Set minimum frequency for k-w processing.  Normally set by DSP.  User modified if using single or fixed modes or auto mode with VF_OP_MODE_SETTINGS set to 1 (FIXED_FREQUENCY).  Go to Idle mode, then set this parameter, then select single/fixed." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1077] ;  /* Hz hertz */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_freq_max
{
    LABEL           "|en|Flow Freq Max" ;
    HELP            "|en|Set maximum frequency for k-w processing.  Normally set by DSP.  User modified if using single or fixed modes or auto mode with VF_OP_MODE_SETTINGS set to 1 (FIXED_FREQUENCY).  Go to Idle mode, then set this parameter, then select single/fixed." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1077] ;  /* Hz hertz */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_rate_min
{
    LABEL           "|en|Flow Rate Min" ;
    HELP            "|en|Minimum valid flow rate reading in configured display units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_rate_max
{
    LABEL           "|en|Flow Rate Max" ;
    HELP            "|en|Maximum valid flow rate reading in configured display units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_min_quality
{
    LABEL           "|en|Flow Min Quality" ;
    HELP            "|en|Minimum quality threshold for VF display and output." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_nyquist_high
{
    LABEL           "|en|Flow Nyquist High" ;
    HELP            "|en|Define high end of frequency range to use for determining flow velocity.  Defined by: FREQUENCY_MAX = (Measured Velocity * VF_NYQUIST_HIGH) / Sensor Spacing. Example: (10 ft/sec*0.7) / 0.2 = 35Hz" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_nyquist_low
{
    LABEL           "|en|Flow Nyquist Low" ;
    HELP            "|en|Define low end of frequency range to use for determining flow velocity.  Defined by: FREQUENCY_MIN = (Measured Velocity * VF_NYQUIST_LOW) / Sensor Spacing. Example: (10 ft/sec*0.3) / 0.2 = 15Hz" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_centroid_width
{
    LABEL           "|en|Flow Centroid Width" ;
    HELP            "|en|Define width of peak to use in calculation of flow rate." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_vel_search_limit_low
{
    LABEL           "|en|Flow Vel Search Limit Low" ;
    HELP            "|en|Define low end of velocity search range to use for determining flow velocity.  Defined by: Velocity_Min = (FREQ_MAX * Sensor Spacing) / VF_SEARCH_LIMIT_LOW. Example: at 10ft/sec, (10 ft/sec*0.7) / 0.2 = 35Hz then  (35Hz * 0.2) / 0.9 = 7.78 ft/sec.  This defines the start ft/sec search point for the actual flow velocity peak.  Must be set greater than value set for VF_NYQUIST_HIGH." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_vel_search_limit_high
{
    LABEL           "|en|Flow Vel Search Limit High" ;
    HELP            "|en|Define high end of velocity search range to use for determining flow velocity.  Defined by: Velocity_Max = (FREQ_MIN * Sensor Spacing) / VF_SEARCH_LIMIT_HIGH. Example: at 10ft/sec, (10 ft/sec*0.3) / 0.2 = 15Hz then  (15Hz * 0.2) / 0.15 = 20 ft/sec.  This defines the start ft/sec search point for the actual flow velocity peak.  Must be set less than value for VF_NYQUIST_LOW." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_algorithm_flow_nyquist_initial_value
{
    LABEL           "|en|Flow Nyquist Initial Value" ;
    HELP            "|en|This parameter selects the k value (from k-w) where the algorithm initially searches for the flow rate." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_decimation
{
    LABEL           "|en|Flow Decimation" ;
    HELP            "|en|Flow Decimation" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_window_type
{
    LABEL           "|en|Flow Window Type" ;
    HELP            "|en|Algorithms always use hanning window.  Windows raw data samples of NFFT size, then zero pads, then computes FFT." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_detrend
{
    LABEL           "|en|Flow Detrend" ;
    HELP            "|en|Enable/disable detrend of time series data of NFFT size before windowing and zero padding. 0 - Do not detrend time series data, 1 - Detrend time series data." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_normalization
{
    LABEL           "|en|Flow Normalization" ;
    HELP            "|en|Enable/disable normalization of sensor data. 0 - No normalization, 1 - Normalize data.  Normalization performed in frequency domain." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_differencing
{
    LABEL           "|en|Flow Differencing" ;
    HELP            "|en|Enable/disable differencing of sensors.  0 - No differencing, 1 - difference sensors using first order differencing. (i.e. Ch1=S1-S2, Ch2=S2-S3...Ch7=S7-S8).  2 - second order differencing (i.e. Ch1=S1-2*S2+S3, Ch2=S2-2*S3+S4...) Calculation performed in frequency domain." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_direction
{
    LABEL           "|en|Flow Direction" ;
    HELP            "|en|Define flow direction." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_window_size_multiplier
{
    LABEL           "|en|Flow Window Size Multiplier" ;
    HELP            "|en|Default values are normally OK. Define target number of passes through array per calculation for volumetric flow.  Use with caution." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_peak_search_mode
{
    LABEL           "|en|Flow Peak Search Mode" ;
    HELP            "|en|0 - Velocity search limits set to FLOW_MIN and FLOW_MAX, 1 - Velocity search limits defined by VF_SEARCH_LIMIT_LOW and VF_SEARCH_LIMIT_HIGH." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_operating_mode
{
    LABEL           "|en|Flow Operating Mode" ;
    HELP            "|en|Determines which VF parameters to fix or calculate during a VF calculation and whether or not to use Linear/Log KW diff.  Bit Mapped Values: 0: Dynamic frequency adjust in auto runmode (original calculation) 1: Fixed frequency in auto run mode 2: Fixed blocks in auto run mode 4: Dynamic Nyquist calculation enable 8: Reserved for future use 16: Linear KW diff enable 32: Log KW diff enable" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_quality_mode
{
    LABEL           "|en|Flow Quality Mode" ;
    HELP            "|en|0 selects original VF quality calculation, 1 selects new VF quality calculation." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_flow_bi_direction          
{
    LABEL       "|en|Flow Bi Direction" ;
    HELP        [blank] ;
    CLASS       CONTAINED ;
    TYPE        ENUMERATED(1)
    {
        {   0,  "REV"   },
        {   1,  "FWD"   },
        {   2,  "BIDIR" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING    READ & WRITE ;
}


/*--------------------------------------------------------- index 23 ------*/

VARIABLE    tb_flow_algorithm_dynamic_flow_data_length
{
    LABEL           "|en|Flow Data Length" ;
    HELP            "|en|Define number of blocks used for calculations." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_dynamic_flow_window_size
{
    LABEL           "|en|Flow Window Size" ;
    HELP            "|en|Number of points used in FFT.  Actual FFT size is next 2^n higher value.  Value of NFFT is zero padded to next larger 2^n FFT size.  This value is normally set by the DSP." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_dynamic_flow_window_overlap
{
    LABEL           "|en|Flow Window Overlap" ;
    HELP            "|en|Define overlap of FFT windows.  This value is normally set by DSP to half of NFFT." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_algorithm_dynamic_flow_window_averages
{
    LABEL           "|en|Flow Window Averages" ;
    HELP            "|en|Default values are normally OK. In general, for slower flow rates, use more FFT averages, for faster flow rates, use fewer FFT averages.  This parameter affects the number of blocks used (there is a 20 block maximum due to DSP memory limitations).  Use with caution." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

/*--------------------------------------------------------- index 24 ------*/

VARIABLE    tb_flow_calibration_flow_cal_coeff_c0
{
    LABEL           "|en|Flow Cal Coeff C0" ;
    HELP            "|en|Volumetric flow calibration coefficient C0." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_calibration_flow_cal_coeff_c1
{
    LABEL           "|en|Flow Cal Coeff C1" ;
    HELP            "|en|Volumetric flow calibration coefficient C1." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_calibration_flow_cal_coeff_c2
{
    LABEL           "|en|Flow Cal Coeff C2" ;
    HELP            "|en|Volumetric flow calibration coefficient C2." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}


/*--------------------------------------------------------- index 25 ------*/

VARIABLE    tb_sos_algorithm_sos_sample_freq
{
    LABEL           "|en|SOS Sample Freq" ;
    HELP            "|en|Set sample frequency for SOS mode.  This parameter must be set for SOS, and overrides the SAMPLE_FREQ setting if running in SOS mode.    Enter one of the following: 3906.25, 2055.921." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1077] ;  /* Hz hertz */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_freq_min
{
    LABEL           "|en|SOS Freq Min" ;
    HELP            "|en|Minimum frequency to use for SOS calculation.  Typically in the 100 to 500hz range.  Depends upon the data quality as seen on the k-w plot.  SOS_FREQ_MIN and SOS_FREQ_MAX set the frequency range over which the SOS calculation will be performed.  The larger this range, the longer the calculations will take." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1077] ;  /* Hz hertz */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_freq_max
{
    LABEL           "|en|SOS Freq Max" ;
    HELP            "|en|Maximum frequency to use for SOS calculation.  Typically in the 800 to 1500hz range.  Depends upon the data quality as seen on the k-w plot.  SOS_FREQ_MIN and SOS_FREQ_MAX set the frequency range over which the SOS calculation will be performed.  The larger this range, the longer the calculations will take." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1077] ;  /* Hz hertz */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_min
{
    LABEL           "|en|SOS Min" ;
    HELP            "|en|Minimum SOS value to search for.  If too much energy (such as from a high velocity vortical ridge) causes the algorithms to calculate a sound speed below that of the main SOS ridge, this parameter may need to be increased.  Care must be taken not to set this higher than the expected minimum SOS for the application." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_max
{
    LABEL           "|en|SOS Max" ;
    HELP            "|en|Maximum SOS value to search for.  If too much energy along the 0 k value on the k-w plot and algorithms are calculating SOS_MAX, even when SOS ridge indicates an SOS below this value, may need to decrease this parameter.  Care must be taken not to set this lower than the expected maximum SOS for the application." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_min_quality
{
    LABEL           "|en|SOS Min Quality" ;
    HELP            "|en|Minimum quality threshold for SOS/GVF display and output." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_centroid_width
{
    LABEL           "|en|SOS Centroid Width" ;
    HELP            "|en|Define width of peak to use in calculation of SOS." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_frequency_threshold
{
    LABEL           "|en|SOS Frequency Threshold" ;
    HELP            "|en|This value selects the threshold that the second derivative of a power array (generated at a specific frequency over all k-space values) must break in order for the specific frequency point to be considered a valid frequency point." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_min_k
{
    LABEL           "|en|SOS Min k" ;
    HELP            "|en|This value sets the lower limit in k-space that is used in the SOS auto frequency determination code.  This value is equal to the first k-space bin after 0: PI/deltaX/50 (there are 50 bins from 0 to PI/deltaX)." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_max_k
{
    LABEL           "|en|SOS Max k" ;
    HELP            "|en|This value sets the upper limit in k-space that is used in the SOS auto frequency determination code.  This value is equal to the last k-space bin: PI/deltaX." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_search_limit
{
    LABEL           "|en|SOS Search Limit" ;
    HELP            "|en|This value is the +/-percentage of the estimated SOS value  (calculated using the auto frequency calculation code) that determines the lower (Estimated SOS * 0.5) and upper (Estimated SOS * 1.5) SOS search limits." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_lambda_diam
{
    LABEL           "|en|SOS Lambda Diam" ;
    HELP            "|en|Used to calculate the SOS dynamic frequency maximum used when calculating SOS.SOS Max Freq = (Max SOS search)/(Lambda Diameter * (Pipe Diameter/12))." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sos_algorithm_sos_total_data
{
    LABEL           "|en|SOS Total Data" ;
    HELP            "|en|Calculates SOS Samples from this value and SOS Sample Frequency: SOS Samples = SOS Total Data * SOS Sample Freq." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_window_size
{
    LABEL           "|en|SOS Window Size" ;
    HELP            "|en|Number of FFT points to use in SOS calculation.  Usually set to 1/8 or 1/4 of the sample frequency" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_window_overlap
{
    LABEL           "|en|SOS Window Overlap" ;
    HELP            "|en|Number of sample point overlap between successive FFT's.  Recommended to set this to 50% of SOS_FFT_POINTS." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_sub_array_size
{
    LABEL           "|en|SOS Sub Array Size" ;
    HELP            "|en|SOS Sub Array Size" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_normalization
{
    LABEL           "|en|SOS Normalization" ;
    HELP            "|en|0 selects NO normalization in the frequency domain. 1 selects normalization in the frequency domain." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_differencing
{
    LABEL           "|en|SOS Differencing" ;
    HELP            "|en|0 selects NO differencing in the frequency domain. 1 selects 1st order differencing in the frequency domain. 2 selects 2nd order differencing in the frequency domain." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_operating_mode
{
    LABEL           "|en|SOS Operating Mode" ;
    HELP            "|en|Determines which ridge to use for SOS calculation. Also determines which SOS parameter to leave fixed or calculate and whether or not to use Linear/Log KW diff.  Bit Mapped Values: 0: Use right and left ridge averaged 1: Use right ridge only 2: Use left ridge only 4: Enable SOS auto frequency calculation 8: Enable SOS power weighting to autofrequency calculation 16: Linear KW diff enable 32: Log KW diff enable." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_selection_threshold
{
    LABEL           "|en|SOS Selection Threshold" ;
    HELP            "|en|SOS Selection Threshold" ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sos_algorithm_sos_min_freq_points
{
    LABEL           "|en|SOS Min Freq Points" ;
    HELP            "|en|This value selects the minimum number of frequency points that will be used in the SOS calculation. If this number is not met then the calculation is not performed and an error is reported." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}


/*--------------------------------------------------------- index 26 ------*/


VARIABLE    tb_sos_algorithm_dynamic_sos_valid_freq_pts_right
{
    LABEL           "|en|SOS Valid Freq Pts Right" ;
    HELP            "|en|The number of frequency points used from the right ridge of the k-w plot." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sos_algorithm_dynamic_sos_valid_freq_pts_left
{
    LABEL           "|en|SOS Valid Freq Pts Left" ;
    HELP            "|en|The number of frequency points used from the left ridge of the k-w plot." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

/*--------------------------------------------------------- index 27 ------*/

VARIABLE    tb_spl_acoustic_level_spl_min_freq
{
    LABEL           "|en|SPL Minimum Frequency" ;
    HELP            [blank] ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_spl_acoustic_level_spl_max_freq
{
    LABEL           "|en|SPL Maximum Frequency" ;
    HELP            [blank] ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_spl_acoustic_level_al_min_freq
{
    LABEL           "|en|AL Minimum Frequency" ;
    HELP            [blank] ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_spl_acoustic_level_al_max_freq
{
    LABEL           "|en|AL Maximum Frequency" ;
    HELP            [blank] ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_spl_acoustic_level_al_fft_points
{
    LABEL           "|en|AL FFT Points" ;
    HELP            [blank] ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 28 ------*/

VARIABLE    tb_analog_section_analog_sensor_input_units_1
{
    LABEL           "|en|Analog Sensor Input 1 Units" ;
    HELP            "|en|Selects units used in translating the mA measured on Sensor 1 input to units used internally." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_input_units_2
{
    LABEL           "|en|Analog Sensor Input 2 Units" ;
    HELP            "|en|Selects units used in translating the mA measured on Sensor 2 input to units used internally." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_input_scale_1
{
    LABEL           "|en|Analog Sensor Input 1 Scale" ;
    HELP            "|en|Sets multiplier used to scale the sensor input 1 value." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_input_scale_2
{
    LABEL           "|en|Analog Sensor Input 2 Scale" ;
    HELP            "|en|Sets multiplier used to scale the sensor input 2 value." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_input_offset_1
{
    LABEL           "|en|Analog Sensor Input 1 Offset" ;
    HELP            "|en|Sets offset applied to the input sensor input 1 value." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_input_offset_2
{
    LABEL           "|en|Analog Sensor Input 2 Offset" ;
    HELP            "|en|Sets offset applied to the input sensor input 2 value." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_1_1st_order_damping_filter_enable
{
    LABEL           "|en|Analog Sensor Input 1 Damping Filter Control" ;
    HELP            "|en|Enables or disables 1st order damping filter for sensor input 1." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "Disable",   "OFF" },
        { 0x01,  "Enable",   "ON" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_2_1st_order_damping_filter_enable
{
    LABEL           "|en|Analog Sensor Input 2 Damping Filter Control" ;
    HELP            "|en|Enables or disables 1st order damping filter for sensor input 2." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "Disable",   "OFF" },
        { 0x01,  "Enable",   "ON" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_1_damping_tau
{
    LABEL           "|en|Analog Sensor Input 1 Damping Tau" ;
    HELP            "|en|Damping time in seconds for the damping filter for sensor input 1." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_analog_section_analog_sensor_2_damping_tau
{
    LABEL           "|en|Analog Sensor Input 2 Damping Tau" ;
    HELP            "|en|Damping time in seconds for the damping filter for sensor input 2." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 29 ------*/

VARIABLE    tb_input_units_pressure_input_units
{
    LABEL           "|en|Pressure Input Units" ;
    HELP            "|en|Selects units for pressure read from Fieldbus AO Channel 10." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }

    HANDLING        READ & WRITE ;
}

VARIABLE    tb_input_units_temperature_input_units
{
    LABEL           "|en|Temperature Input Units" ;
    HELP            "|en|Selects units for temperature read from Fieldbus AO Channel 11." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }

    HANDLING        READ & WRITE ;
}

VARIABLE    tb_input_units_input_1_units
{
    LABEL           "|en|Input 1 Units" ;
    HELP            "|en|Selects units for input 1 read from Fieldbus AO Channel 12." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }

    HANDLING        READ & WRITE ;
}

VARIABLE    tb_input_units_input_2_units
{
    LABEL           "|en|Input 2 Units" ;
    HELP            "|en|Selects units for input 2 read from Fieldbus AO Channel 13." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }

    HANDLING        READ & WRITE ;
}

VARIABLE    tb_input_units_input_3_units
{
    LABEL           "|en|Input 3 Units" ;
    HELP            "|en|Selects units for input 3 read from Fieldbus AO Channel 14." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (2)
    {
               { 0, "None"},
               { 1143, [unit_1143], [unit_1143_help] }, /* PSIg */
               { 1548, [unit_1548], [unit_1548_help] }, /* kPSAg*/
               /*{ 1137, [unit_1137], [unit_1137_help] },*/ /* BAR  */
               { 32768, "Barg", "bar guage" },          /* BARG  */
               { 1001, [unit_1001], [unit_1001_help] }, /* ^C  */
               { 1002, [unit_1002], [unit_1002_help] }  /* ^F  */
    }

    HANDLING        READ & WRITE ;
}


/*--------------------------------------------------------- index 30 ------*/

VARIABLE    tb_flow_nr_filter_enable
{
    LABEL           "|en|Flow NR Filter Control" ;
    HELP            "|en|Enables or disables the flow noise reduction filter." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "DISABLE",   "DISABLE" },
        { 0x01,  "ENABLE",   "ENABLE" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_nr_filter_magnitude_selection
{
    LABEL           "|en|Flow NR Filter Magnitude Selection" ;
    HELP            "|en|Selects flow noise reduction filter magnitude." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "LOW",   "LOW" },
        { 0x01,  "HIGH",   "HIGH" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 31 ------*/

VARIABLE    tb_flow_damping_filter_flow_1st_order_damping_filter_enable
{
    LABEL           "|en|Flow 1st Order Damping Filter Control" ;
    HELP            "|en|Enables or disables flow 1st order damping filter." ;
    CLASS           CONTAINED ;

    TYPE            ENUMERATED (1)
    {
        { 0x00,  "DISABLE",   "DISABLE" },
        { 0x01,  "ENABLE",   "ENABLE" }
    }

    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_damping_filter_flow_damping_tau
{
    LABEL           "|en|Flow Damping Tau" ;
    HELP            "|en|Sets tau value for flow 1st order damping filter." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 32 ------*/

VARIABLE    tb_flow_spike_filter_enable
{
    LABEL           "|en|Flow Spike Filter Control" ;
    HELP            "|en|Enables or disables flow spike filter." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "DISABLE",  "DISABLE"},
        { 0x01,  "ENABLE",  "ENABLE"}
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_spike_filter_no_flow_length
{
    LABEL           "|en|Flow Spike Filter No Flow Length" ;
    HELP            "|en|Defines the required number of consecutive measurements with good quality before a measurement is deemed valid and displayed." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_spike_filter_length
{
    LABEL           "|en|Flow Spike Filter Length" ;
    HELP            "|en|This parameter is used when the device is 'Holding' a previous measurement due to a new measurement with bad quality. The definition of this parameter is the required number of consecutive measurements with bad quality before the device enters the 'No Flow' state and displays dashes." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_spike_filter_up_count
{
    LABEL           "|en|Flow Spike Filter Up Count" ;
    HELP            "|en|Each time a measurement with bad quality is made 'Up Count' is added to the quality counter. If the counter becomes less than or equal to zero then the present measurement is displayed. If the quality counter becomes greater than or equal to ('Filter Length' x 'Up Count') then the device is forced into a 'No Flow' condition and displays dashes." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_spike_filter_down_count
{
    LABEL           "|en|Flow Spike Filter Down Count" ;
    HELP            "|en|Each time a measurement with good quality is made 'Down Count' is subtracted from the quality counter. If the quality counter becomes less than or equal to zero then the present measurement is displayed. If the quality counter becomes greater than or equal to ('Filter Length' x 'Up Count') then the device is forced into a 'No Flow' condition and displays dashes." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_flow_spike_filter_percentage
{
    LABEL           "|en|Flow Spike Filter Percentage" ;
    HELP            "|en|After 'Percent Len' measurements with good quality have been displayed a new measurement with good quality is deemed valid and displayed when the difference between the maximum and minimum of the present measurement and ('Percent Len' - 1) previous consecutive measurements is less than the measurement range (default of 27fps for Flow) times ('Percent' / 100)." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1342] ;   /* % percent */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_flow_spike_filter_pct_window_len
{
    LABEL           "|en|Flow Spike Filter Percent Window Length" ;
    HELP            "|en|After 'Percent Len' measurements with good quality have been displayed a new measurement with good quality is deemed valid and displayed when the difference between the maximum and minimum of the present measurement and ('Percent Len' - 1) previous consecutive measurements is less than the measurement range (default of 27fps for Flow) times ('Percent' / 100)." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}


/*--------------------------------------------------------- index 33 ------*/

VARIABLE    tb_gvf_nr_filter_enable
{
    LABEL           "|en|GVF NR Filter Control" ;
    HELP            "|en|Enables or disables the GVF noise reduction filter." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "DISABLE",   "DISABLE" },
        { 0x01,  "ENABLE",   "ENABLE" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_gvf_nr_filter_magnitude_selection
{
    LABEL           "|en|GVF NR Filter Magnitude Selection" ;
    HELP            "|en|Selects GVF noise reduction filter magnitude." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "LOW",   "LOW" },
        { 0x01,  "HIGH",   "HIGH" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 34 ------*/

VARIABLE    tb_gvf_damping_filter_enable
{
    LABEL           "|en|GVF 1st Order Damping Filter Control" ;
    HELP            "|en|Enables or disables GVF 1st order damping filter." ;
    CLASS           CONTAINED ;

    TYPE            ENUMERATED (1)
    {
        { 0x00,  "DISABLE",   "DISABLE" },
        { 0x01,  "ENABLE",   "ENABLE" }
    }

    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_gvf_damping_filter_tau
{
    LABEL           "|en|GVF Damping Tau" ;
    HELP            "|en|Sets tau value for GVF 1st order damping filter." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1054] ;   /* s seconds */
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 35 ------*/

VARIABLE    tb_gvf_spike_filter_enable
{
    LABEL           "|en|GVF Spike Filter Control" ;
    HELP            "|en|Enables or disables GVF spike filter." ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        { 0x00,  "DISABLE",  "DISABLE" },
        { 0x01,  "ENABLE",    "ENABLE" }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_gvf_spike_filter_no_gvf_length
{
    LABEL           "|en|GVF Spike Filter No Flow Length" ;
    HELP            "|en|Defines the required number of consecutive measurements with good quality before a measurement is deemed valid and displayed." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_gvf_spike_filter_length
{
    LABEL           "|en|GVF Spike Filter Length" ;
    HELP            "|en|This parameter is used when the device is 'Holding' a previous measurement due to a new measurement with bad quality. The definition of this parameter is the required number of consecutive measurements with bad quality before the device enters the 'No Flow' state and displays dashes." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_gvf_spike_filter_up_count
{
    LABEL           "|en|GVF Spike Filter Up Count" ;
    HELP            "|en|Each time a measurement with bad quality is made 'Up Count' is added to an entity called the quality counter. If the quality counter becomes less than or equal to zero then the present measurement is displayed. If the quality counter becomes greater than or equal to ('Filter Length' x 'Up Count') then the device is forced into a 'No Flow' condition and displays dashes." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_gvf_spike_filter_down_count
{
    LABEL           "|en|GVF Spike Filter Down Count" ;
    HELP            "|en|Each time a measurement with good quality is made 'Down Count' is subtracted from the quality counter. If the quality counter becomes less than or equal to zero then the present measurement is displayed. If the quality counter becomes greater than or equal to ('Filter Length' x 'Up Count') then the device is forced into a 'No Flow' condition and displays dashes." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_gvf_spike_filter_percentage
{
    LABEL           "|en|GVF Spike Filter Percentage" ;
    HELP            "|en|After 'Percent Len' measurements with good quality have been displayed a new measurement with good quality is deemed valid and displayed when the difference between the maximum and minimum of the present measurement and ('Percent Len' - 1) previous consecutive measurements is less than the measurement range (default of 27fps for Flow) times ('Percent' / 100)." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1342] ;   /* % percent */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_gvf_spike_filter_filt_pct_window_len
{
    LABEL           "|en|GVF Spike Filter Percent Window Length" ;
    HELP            "|en|After 'Percent Len' measurements with good quality have been displayed a new measurement with good quality is deemed valid and displayed when the difference between the maximum and minimum of the present measurement and ('Percent Len' - 1) previous consecutive measurements is less than the measurement range (default of 27fps for Flow) times ('Percent' / 100)." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (1) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

/*--------------------------------------------------------- index 36 ------*/

VARIABLE    tb_sensor_sensorhead_serial_number
{
    LABEL           "|en|Sensorhead Serial Number" ;
    HELP            "|en|Sensorhead Serial Number" ;
    CLASS           CONTAINED ;
    TYPE            ASCII (16) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}


VARIABLE    tb_sensor_threshold_max
{
    LABEL           "|en|Sensor Threshold Max" ;
    HELP            "|en|Sets maximum threshold for sensor health diagnostics (in A/D counts)." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sensor_threshold_min
{
    LABEL           "|en|Sensor Threshold Min" ;
    HELP            "|en|Sets minimum threshold for sensor health diagnostics (in A/D counts)." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sensor_band_temp_rating
{
    LABEL           "|en|Band Temperature Rating" ;
    HELP            "|en|Band Temperature Rating" ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        {   0,  "85"    },
        {   1,  "125"   }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}


VARIABLE    tb_sensor_band_type
{
    LABEL           "|en|Band Type" ;
    HELP            "|en|Band Type" ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        {   0,  "Full"      },
        {   1,  "Split"     },
        {   2,  "Custom"    }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sensor_band_active_area
{
    LABEL           "|en|Band Active Area" ;
    HELP            "|en|Band Active Area" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}


VARIABLE   tb_sensor_scale_temp_source
{
    LABEL           "|en|Sensor Scale Temperature Source" ;
    HELP            "|en|Sensor Scale Temperature Source" ;
    CLASS           CONTAINED ;
    TYPE            ENUMERATED (1)
    {
        {   0,  "Fixed"      },
        {   1,  "Band"     }
    }
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sensor_scale_comp_temperature
{
    LABEL           "|en|Sensor Scale Compare Temperature" ;
    HELP            "|en|Sensor Scale Compare Temperature" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE;
}

VARIABLE    tb_sensor_scale_temp_factor
{
    LABEL           "|en|Sensor Scale Factor" ;
    HELP            "|en|Sensor Scale Factor" ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ;
}

/*--------------------------------------------------------- index 37 ------*/

VARIABLE    tb_sensor_spacing_sensor_1_location
{
    LABEL           "|en|Sensor 1 Location" ;
    HELP            "|en|Starting point for sensor 1.  Typically 0." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_2
{
    LABEL           "|en|Sensor Spacing 1-2" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 2." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_3
{
    LABEL           "|en|Sensor Spacing 1-3" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 3." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_4
{
    LABEL           "|en|Sensor Spacing 1-4" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 4." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_5
{
    LABEL           "|en|Sensor Spacing 1-5" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 5." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_6
{
    LABEL           "|en|Sensor Spacing 1-6" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 6." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_7
{
    LABEL           "|en|Sensor Spacing 1-7" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 7." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_spacing_1_8
{
    LABEL           "|en|Sensor Spacing 1-8" ;
    HELP            "|en|Distance in feet between sensor 1 and sensor 8." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1018] ;   /* ft feet */
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 38 ------*/

VARIABLE    tb_sensor_scale_factor_1
{
    LABEL           "|en|Sensor Scale Factor 1" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 1." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_2
{
    LABEL           "|en|Sensor Scale Factor 2" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 2." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_3
{
    LABEL           "|en|Sensor Scale Factor 3" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 3." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_4
{
    LABEL           "|en|Sensor Scale Factor 4" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 4." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_5
{
    LABEL           "|en|Sensor Scale Factor 5" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 5." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_6
{
    LABEL           "|en|Sensor Scale Factor 6" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 6." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_7
{
    LABEL           "|en|Sensor Scale Factor 7" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 7." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

VARIABLE    tb_sensor_scale_factor_8
{
    LABEL           "|en|Sensor Scale Factor 8" ;
    HELP            "|en|Scaling factor in volts per PSI for sensor 8." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ & WRITE ;
}

/*--------------------------------------------------------- index 39 ------*/


VARIABLE    tb_measured_values_flow_quality
{
    LABEL           "|en|Flow Quality" ;
    HELP            "|en|Measured flow quality." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_flow_rate_unfiltered
{
    LABEL           "|en|Flow Rate Unfiltered" ;
    HELP            "|en|Measured flow rate in ft/s without any filtering applied." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1067] ;   /* ft/s feet per second */
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_pressure
{
    LABEL           "|en|Pressure" ;
    HELP            "|en|Pressure as used in calculation of GVF in configured units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_temperature
{
    LABEL           "|en|Temperature" ;
    HELP            "|en|Temperature as used in calculation of GVF in configured units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_sos_quality
{
    LABEL           "|en|SOS Quality" ;
    HELP            "|en|Measured sos quality." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_sos_unfiltered
{
    LABEL           "|en|SOS Unfiltered" ;
    HELP            "|en|Measured SOS in ft/s without any filtering applied." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1067] ;   /* ft/s feet per second */
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_sos_flow_rate
{
    LABEL           "|en|SOS Flow Rate" ;
    HELP            "|en|Measured SOS flow rate." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_sos_flow_qual
{
    LABEL           "|en|SOS Flow Quality" ;
    HELP            "|en|Measured SOS flow quality." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_tlf
{
    LABEL           "|en|TLF" ;
    HELP            "|en|Measured True Liquid Flow in configured flow units." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_total_tlf
{
    LABEL           "|en|Total TLF" ;
    HELP            "|en|Measured total TLF." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_tlf_unfiltered
{
    LABEL           "|en|TLF Unfiltered" ;
    HELP            "|en|Measured TLF in ft/s without any filtering applied." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1067] ;   /* ft/s feet per second */
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_analog_4_20ma_input_1
{
    LABEL           "|en|Analog 4-20ma Input 1" ;
    HELP            "|en|Measured analog input 1 in mA." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1211] ;   /* mA milliamperes */
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_analog_4_20ma_input_2
{
    LABEL           "|en|Analog 4-20ma Input 2" ;
    HELP            "|en|Measured analog input 2 in mA." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [unit_1211] ;   /* mA milliamperes */
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_total_flow_fraction
{
    LABEL           "|en|Total Flow Fraction" ;
    HELP            "|en|Floating point fraction to be added to 'Total Flow Carry' * 100 to calculate full resolution total flow." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_total_tlf_fraction
{
    LABEL           "|en|Total TLF Fraction" ;
    HELP            "|en|Floating point fraction to be added to 'Total TLF Carry' * 100 to calculate full resolution total TLF." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_total_flow_carry
{
    LABEL           "|en|Total Flow Carry" ;
    HELP            "|en|Signed long portion (* 100) to be added to 'Total Flow Fraction' to calculate full resolution total flow." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_total_tlf_carry
{
    LABEL           "|en|Total TLF Carry" ;
    HELP            "|en|Signed long portion (* 100) to be added to 'Total TLF Fraction' to calculate full resolution total TLF." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_measured_values_system_status
{
    LABEL           "|en|System Status" ;
    HELP            "|en|Refer to manual for description of individual bits." ;
    CLASS           CONTAINED ;
    TYPE            UNSIGNED_INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

/*--------------------------------------------------------- index 40 ------*/

VARIABLE  tb_flow_rate_value
{
    LABEL       "|en|Flow Rate" ;
    HELP        "|en|Measured flow rate in configured units." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_flow_rate_status
{
    LABEL       "|en|Flow Rate Status" ;
    HELP        "|en|Status of flow rate process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 41 ------*/

VARIABLE  tb_gvf_value
{
    LABEL       "|en|GVF" ;
    HELP        "|en|Measured Gas Volume Fraction in percent." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_gvf_status
{
    LABEL       "|en|GVF Status" ;
    HELP        "|en|Status of Gas Volume Fraction process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 42 ------*/

VARIABLE  tb_sos_value
{
    LABEL       "|en|SOS" ;
    HELP        "|en|Measured Speed of sound in configured units." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_sos_status
{
    LABEL       "|en|SOS Status" ;
    HELP        "|en|Status of Speed of sound process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 43 ------*/

VARIABLE  tb_sensorhead_temperature_value
{
    LABEL       "|en|Sensorhead Temperature" ;
    HELP        "|en|measured sensorhead temperature in C." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_sensorhead_temperature_status
{
    LABEL       "|en|Sensorhead Temperature Status" ;
    HELP        "|en|Status of sensorhead temperature process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 44 ------*/

VARIABLE  tb_total_flow_value
{
    LABEL       "|en|Total Flow" ;
    HELP        "|en|Total flow in configured units." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_total_flow_status
{
    LABEL       "|en|Total Flow Status" ;
    HELP        "|en|Status of total flow process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 45 ------*/

VARIABLE  tb_acoustic_level_value
{
    LABEL       "|en|Acoustic Level" ;
    HELP        "|en|Measured Acoustic Level in dB" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_acoustic_level_status
{
    LABEL       "|en|Acoustic Level Status" ;
    HELP        "|en|Status of acoustic level process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 46 ------*/

VARIABLE  tb_output_0_value
{
    LABEL       "|en|Output 0" ;
    HELP        "|en|Output 0" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_output_0_status
{
    LABEL       "|en|Output 0 Status" ;
    HELP        "|en|Status of output 0 process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}


/*--------------------------------------------------------- index 47 ------*/

VARIABLE  tb_output_1_value
{
    LABEL       "|en|Output 1" ;
    HELP        "|en|Output 1" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_output_1_status
{
    LABEL       "|en|Output 1 Status" ;
    HELP        "|en|Status of output 1 process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 48 ------*/

VARIABLE  tb_output_2_value
{
    LABEL       "|en|Output 2" ;
    HELP        "|en|Output 2" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_output_2_status
{
    LABEL       "|en|Output 2 Status" ;
    HELP        "|en|Status of output 2 process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 49 ------*/

VARIABLE    tb_sensor_max_min_sensor_1_max
{
    LABEL           "|en|Sensor 1 Max" ;
    HELP            "|en|Sensor 1 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_2_max
{
    LABEL           "|en|Sensor 2 Max" ;
    HELP            "|en|Sensor 2 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_sensor_max_min_sensor_3_max
{
    LABEL           "|en|Sensor 3 Max" ;
    HELP            "|en|Sensor 3 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_4_max
{
    LABEL           "|en|Sensor 4 Max" ;
    HELP            "|en|Sensor 4 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_5_max
{
    LABEL           "|en|Sensor 5 Max" ;
    HELP            "|en|Sensor 5 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_6_max
{
    LABEL           "|en|Sensor 6 Max" ;
    HELP            "|en|Sensor 6 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_7_max
{
    LABEL           "|en|Sensor 7 Max" ;
    HELP            "|en|Sensor 7 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_8_max
{
    LABEL           "|en|Sensor 8 Max" ;
    HELP            "|en|Sensor 8 maximum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_1_min
{
    LABEL           "|en|Sensor 1 Min" ;
    HELP            "|en|Sensor 1 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_sensor_max_min_sensor_2_min
{
    LABEL           "|en|Sensor 2 Min" ;
    HELP            "|en|Sensor 2 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_3_min
{
    LABEL           "|en|Sensor 3 Min" ;
    HELP            "|en|Sensor 3 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_4_min
{
    LABEL           "|en|Sensor 4 Min" ;
    HELP            "|en|Sensor 4 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_5_min
{
    LABEL           "|en|Sensor 5 Min" ;
    HELP            "|en|Sensor 5 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_6_min
{
    LABEL           "|en|Sensor 6 Min" ;
    HELP            "|en|Sensor 6 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ  ;
}

VARIABLE    tb_sensor_max_min_sensor_7_min
{
    LABEL           "|en|Sensor 7 Min" ;
    HELP            "|en|Sensor 7 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_max_min_sensor_8_min
{
    LABEL           "|en|Sensor 8 Min" ;
    HELP            "|en|Sensor 8 minimum in A/D bins." ;
    CLASS           CONTAINED ;
    TYPE            INTEGER (4) ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

/*--------------------------------------------------------- index 50 ------*/

VARIABLE    tb_sensor_alpha_1
{
    LABEL           "|en|Sensor 1 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_2
{
    LABEL           "|en|Sensor 2 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_3
{
    LABEL           "|en|Sensor 3 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_4
{
    LABEL           "|en|Sensor 4 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_5
{
    LABEL           "|en|Sensor 5 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_6
{
    LABEL           "|en|Sensor 6 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_7
{
    LABEL           "|en|Sensor 7 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

VARIABLE    tb_sensor_alpha_8
{
    LABEL           "|en|Sensor 8 Alpha" ;
    HELP            "|en|Relative scale factor between signal magnitudes acquired from each sensor." ;
    CLASS           CONTAINED ;
    TYPE            FLOAT ;
    CONSTANT_UNIT   [blank] ;
    HANDLING        READ ;
}

/*--------------------------------------------------------- index 51 ------*/

VARIABLE  tb_pressure_input_value
{
    LABEL       "|en|Pressure Input" ;
    HELP        "|en|Pressure used in GVF calculation." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_pressure_input_status
{
    LABEL       "|en|Pressure Input Status" ;
    HELP        "|en|Status of pressure input process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 52 ------*/

VARIABLE  tb_temperature_input_value
{
    LABEL       "|en|Temperature Input" ;
    HELP        "|en|Temperature used in GVF calculation." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_temperature_input_status
{
    LABEL       "|en|Temperature Input Status" ;
    HELP        "|en|Status of temperature input process variable." ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 53 ------*/

VARIABLE  tb_input_1_value
{
    LABEL       "|en|Input 1" ;
    HELP        "|en|Input 1" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_input_1_status
{
    LABEL       "|en|Input 1 Status" ;
    HELP        "|en|Input 1 Status" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 54 ------*/


VARIABLE  tb_input_2_value
{
    LABEL       "|en|Input 2" ;
    HELP        "|en|Input 2" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_input_2_status
{
    LABEL       "|en|Input 2 Status" ;
    HELP        "|en|Input 2 Status" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 55 ------*/


VARIABLE  tb_input_3_value
{
    LABEL       "|en|Input 3" ;
    HELP        "|en|Input 3" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE  FLOAT;
    HANDLING  READ;
}

VARIABLE  tb_input_3_status
{
    LABEL       "|en|Input 3 Status" ;
    HELP        "|en|Input 3 Status" ;
    CLASS CONTAINED & DYNAMIC;
    TYPE        ENUMERATED (1)
    {
            DEFAULT_VALUE   0;
            STATUS_GENERAL
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 56 ------*/

VARIABLE  tb_pa_slave_info_firmware_revision
{
    LABEL "Firmware Revision";
    HELP  [blank];
    CLASS CONTAINED;
    TYPE  ASCII (32) ;
    HANDLING  READ;
}

VARIABLE  tb_pa_slave_info_node_address
{
    LABEL "PA Node Address";
    HELP  [blank];
    CLASS CONTAINED;
    TYPE  INTEGER (1);
    HANDLING  READ;
}

VARIABLE  tb_pa_slave_info_block_mode_phy
{
    LABEL "PHY Block Mode";
    HELP  [blank];
    CLASS CONTAINED;
    TYPE  INTEGER (1)
    {
        DEFAULT_VALUE 0x08;
        { 0x08, [mode_AUTO] },
        { 0x80, [mode_OUT_OF_SERVICE] }
    }
    HANDLING  READ;
}

VARIABLE  tb_pa_slave_info_block_mode_tb
{
    LABEL "TB Block Mode";
    HELP  [blank];
    CLASS CONTAINED;
    TYPE  INTEGER (1)
    {
      DEFAULT_VALUE 0x08;
      { 0x08, [mode_AUTO] },
      { 0x80, [mode_OUT_OF_SERVICE] }
    }
    HANDLING  READ;
}

VARIABLE  tb_pa_slave_info_slave_mode
{
    LABEL "Slave Mode";
    HELP  [blank];
    CLASS CONTAINED;
    TYPE  ENUMERATED (1)
    {
      { 1, "Stop" },
      { 2, "Clear" },
      { 3, "Operate" }
    }
    HANDLING  READ;
}

VARIABLE  tb_pa_slave_info_slave_ident_number
{
    LABEL "PA Ident Number";
    HELP  [blank];
    CLASS CONTAINED;
    TYPE  INTEGER (2)
    {
      { 45576, "0xB208" },
      { 0x9702, "0x9702" }
    }
    HANDLING  READ;
}

/*--------------------------------------------------------- index 62 ------*/      

VARIABLE  tb_comm_state
{
    LABEL     "|en|Modbus Communication State";
    HELP      "|en|Modbus Communication State";
    CLASS     CONTAINED & DYNAMIC;
    TYPE      ENUMERATED (1)
    {
      {0x00,"|en|No Device Communication"},
      {0x01,"|en|Device Communication ok"}
    }
    HANDLING  READ;
}

/*-------------------------------------------------------------------------*/
/*-------------------------------------------------------------------------*/
/*    COMMAND                                                              */
/*-------------------------------------------------------------------------*/
/*    Standard Parameter (0-7)                                             */
/*-------------------------------------------------------------------------*/

COMMAND read_tb_blk
{
    BLOCK sonar_tb;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
            REQUEST
            {
            }
            REPLY
            {
                    tb_blk_reserve,
                    tb_blk_object,
                    tb_blk_parent_class,
                    tb_blk_class,
                    tb_blk_dd_reference,
                    tb_blk_dd_rev,
                    tb_blk_profile,
                    tb_blk_profile_rev,
                    tb_blk_execution_time,
                    tb_blk_num_parameters,
                    tb_blk_index_view_1,
                    tb_blk_num_view_lists
            }
    }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_st_rev
{
        BLOCK sonar_tb;
        INDEX 1;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        tb_st_rev
                }
        }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_tag_desc
{
        BLOCK sonar_tb;
        INDEX 2;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        tb_tag_desc
                }
        }
}

COMMAND write_tb_tag_desc
{
        BLOCK sonar_tb;
        INDEX 2;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        tb_tag_desc
                }
                REPLY
                {
                }
        }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_strategy
{
        BLOCK sonar_tb;
        INDEX 3;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        tb_strategy
                }
        }
}

COMMAND write_tb_strategy
{
        BLOCK sonar_tb;
        INDEX 3;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        tb_strategy
                }
                REPLY
                {
                }
        }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_alert_key
{
        BLOCK sonar_tb;
        INDEX 4;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        tb_alert_key
                }
        }
}

COMMAND write_tb_alert_key
{
        BLOCK sonar_tb;
        INDEX 4;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        tb_alert_key
                }
                REPLY
                {
                }
        }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_target_mode
{
        BLOCK sonar_tb;
        INDEX 5;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        tb_target_mode
                }
        }
}

COMMAND write_tb_target_mode
{
        BLOCK sonar_tb;
        INDEX 5;
        OPERATION WRITE;
        TRANSACTION
        {
                REQUEST
                {
                        tb_target_mode
                }
                REPLY
                {
                }
        }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_mode
{
        BLOCK sonar_tb;
        INDEX 6;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                         tb_actual_mode,
                         tb_permitted_mode,
                         tb_normal_mode
                }
        }
}

/*-------------------------------------------------------------------------*/

COMMAND read_tb_alarm
{
        BLOCK sonar_tb;
        INDEX 7;
        OPERATION READ;
        TRANSACTION
        {
                REQUEST
                {
                }
                REPLY
                {
                        tb_current_state_alarm_sum,
                        tb_unacknowledged_state_alarm_sum,
                        tb_unreported_state_alarm_sum,
                        tb_disabled_state_alarm_sum
                }
        }
}

/*-------------------------------------------------------------------------*/
/*    Additional Parameter                                                 */
/*-------------------------------------------------------------------------*/

/*--------------------------------------------------------- index 13 ------*/

COMMAND read_tb_control
{
      BLOCK sonar_tb;
      INDEX 13;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_control_write_control,
              tb_control_reset_totalizer,
              tb_control_clear_alarm,
              tb_control_clear_data_history
          }
      }
}

COMMAND write_tb_control
{
      BLOCK sonar_tb;
      INDEX 13;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_control_write_control,
              tb_control_reset_totalizer,
              tb_control_clear_alarm,
              tb_control_clear_data_history
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 14 ------*/

COMMAND read_tb_device_info
{
      BLOCK sonar_tb;
      INDEX 14;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_device_info_transmitter_sn,
              tb_device_info_model_number,
              tb_device_info_software_revision,
              tb_device_info_alchemy_software_revision,
              tb_device_info_sensorhead_sn,
              tb_device_info_preamp_software_revision,
              tb_device_info_preamp_serial_number
          }
      }
}


/*--------------------------------------------------------- index 15 ------*/

COMMAND read_tb_pipe_information
{
      BLOCK sonar_tb;
      INDEX 15;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_pipe_info_pipe_diameter_input_mode,
              tb_pipe_info_pipe_diameter_units,
              tb_pipe_info_pipe_id,
              tb_pipe_info_pipe_od,
              tb_pipe_info_pipe_od_wall_units,
              tb_pipe_info_pipe_wall_thickness,
              tb_pipe_info_pipe_size,
              tb_pipe_info_pipe_schedule,
              tb_pipe_info_sos_pipe_wall_thickness_units,
              tb_pipe_info_sos_pipe_wall_thickness,
              tb_pipe_info_sos_pipe_modulus_selection,
              tb_pipe_info_sos_pipe_modulus
          }
      }
}

COMMAND write_tb_pipe_information
{
      BLOCK sonar_tb;
      INDEX 15;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_pipe_info_pipe_diameter_input_mode,
              tb_pipe_info_pipe_diameter_units,
              tb_pipe_info_pipe_id,
              tb_pipe_info_pipe_od,
              tb_pipe_info_pipe_od_wall_units,
              tb_pipe_info_pipe_wall_thickness,
              tb_pipe_info_pipe_size,
              tb_pipe_info_pipe_schedule,
              tb_pipe_info_sos_pipe_wall_thickness_units,
              tb_pipe_info_sos_pipe_wall_thickness,
              tb_pipe_info_sos_pipe_modulus_selection,
              tb_pipe_info_sos_pipe_modulus
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 16 ------*/

COMMAND read_tb_fluid_properties
{
      BLOCK sonar_tb;
      INDEX 16;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_fluid_properties_flow_viscosity,
              tb_fluid_properties_sos_gas_constant_selection,
              tb_fluid_properties_sos_specfic_gravity_selection,
              tb_fluid_properties_sos_liquid_sound_speed_selection,
              tb_fluid_properties_sos_gas_constant,
              tb_fluid_properties_sos_specific_gravity,
              tb_fluid_properties_sos_liquid_sound_speed,
              tb_fluid_properties_sos_polytropic_exponent,
              tb_fluid_properties_sos_liquid_density
          }
      }
}

COMMAND write_tb_fluid_properties
{
      BLOCK sonar_tb;
      INDEX 16;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_fluid_properties_flow_viscosity,
              tb_fluid_properties_sos_gas_constant_selection,
              tb_fluid_properties_sos_specfic_gravity_selection,
              tb_fluid_properties_sos_liquid_sound_speed_selection,
              tb_fluid_properties_sos_gas_constant,
              tb_fluid_properties_sos_specific_gravity,
              tb_fluid_properties_sos_liquid_sound_speed,
              tb_fluid_properties_sos_polytropic_exponent,
              tb_fluid_properties_sos_liquid_density
          }
          REPLY
          {
          }
      }
}


/*--------------------------------------------------------- index 17 ------*/

COMMAND read_tb_environment
{
      BLOCK sonar_tb;
      INDEX 17;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_environment_sos_temperature_input_selection,
              tb_environment_sos_pressure_input_selection,
              tb_environment_sos_temperature_units,
              tb_environment_sos_pressure_units,
              tb_environment_sos_process_temperature,
              tb_environment_sos_process_pressure,
              tb_environment_altitude_units,
              tb_environment_altitude
          }
      }
}

COMMAND write_tb_environment
{
      BLOCK sonar_tb;
      INDEX 17;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_environment_sos_temperature_input_selection,
              tb_environment_sos_pressure_input_selection,
              tb_environment_sos_temperature_units,
              tb_environment_sos_pressure_units,
              tb_environment_sos_process_temperature,
              tb_environment_sos_process_pressure,
              tb_environment_altitude_units,
              tb_environment_altitude
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 18 ------*/

COMMAND read_tb_display
{
      BLOCK sonar_tb;
      INDEX 18;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_display_flow_volume_units,
              tb_display_flow_time_units,
              tb_display_flow_low_cutoff_pct,
              tb_display_flow_high_cutoff_pct,
              tb_display_flow_custom_base_volume_unit,
              tb_display_flow_custom_base_time_unit,
              tb_display_flow_custom_volume_unit_label,
              tb_display_flow_custom_time_unit_label,
              tb_display_flow_custom_volume_unit_multiplier,
              tb_display_flow_custom_time_unit_multiplier,
              tb_display_flow_quality_delta,
              tb_display_gvf_decimal_places,
              tb_display_sos_measurement_units,
              tb_display_sos_quality_delta
          }
      }
}

COMMAND write_tb_display
{
      BLOCK sonar_tb;
      INDEX 18;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_display_flow_volume_units,
              tb_display_flow_time_units,
              tb_display_flow_low_cutoff_pct,
              tb_display_flow_high_cutoff_pct,
              tb_display_flow_custom_base_volume_unit,
              tb_display_flow_custom_base_time_unit,
              tb_display_flow_custom_volume_unit_label,
              tb_display_flow_custom_time_unit_label,
              tb_display_flow_custom_volume_unit_multiplier,
              tb_display_flow_custom_time_unit_multiplier,
              tb_display_flow_quality_delta,
              tb_display_gvf_decimal_places,
              tb_display_sos_measurement_units,
              tb_display_sos_quality_delta
          }
          REPLY
          {
          }
      }
}


/*--------------------------------------------------------- index 19 ------*/

COMMAND read_tb_system
{
      BLOCK sonar_tb;
      INDEX 19;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_system_system_config_mode,
              tb_system_update_rate,
              tb_system_sensors_in_use,
              tb_system_transmitter_gain,
              tb_system_spl_threshold,
              tb_system_write_protect,
              tb_system_idle_timeout,
              tb_system_ethernet_idle_timeout,
              tb_system_out_of_range_mode
          }
      }
}

COMMAND write_tb_system
{
      BLOCK sonar_tb;
      INDEX 19;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_system_system_config_mode,
              tb_system_update_rate,
              tb_system_sensors_in_use,
              tb_system_transmitter_gain,
              tb_system_spl_threshold,
              tb_system_write_protect,
              tb_system_idle_timeout,
              tb_system_ethernet_idle_timeout,
              tb_system_out_of_range_mode
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 20 ------*/

COMMAND read_tb_system_dynamic
{
      BLOCK sonar_tb;
      INDEX 20;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_system_dynamic_spl_average,
              tb_system_dynamic_spl_std_dev
          }
      }
}

/*--------------------------------------------------------- index 21 ------*/

COMMAND read_tb_preamp
{
      BLOCK sonar_tb;
      INDEX 21;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_preamp_gain,
              tb_preamp_auto_gain_mode,
              tb_preamp_charge_gain,
              tb_preamp_gain_0,
              tb_preamp_gain_1,
              tb_preamp_gain_2,
              tb_preamp_gain_3
          }
      }
}

COMMAND write_tb_preamp
{
      BLOCK sonar_tb;
      INDEX 21;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_preamp_gain,
              tb_preamp_auto_gain_mode,
              tb_preamp_charge_gain,
              tb_preamp_gain_0,
              tb_preamp_gain_1,
              tb_preamp_gain_2,
              tb_preamp_gain_3
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 22 ------*/

COMMAND read_tb_flow_algorithm
{
      BLOCK sonar_tb;
      INDEX 22;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_flow_algorithm_flow_sample_freq,
              tb_flow_algorithm_flow_channel_skew,
              tb_flow_algorithm_flow_freq_min,
              tb_flow_algorithm_flow_freq_max,
              tb_flow_algorithm_flow_rate_min,
              tb_flow_algorithm_flow_rate_max,
              tb_flow_algorithm_flow_min_quality,
              tb_flow_algorithm_flow_nyquist_high,
              tb_flow_algorithm_flow_nyquist_low,
              tb_flow_algorithm_flow_centroid_width,
              tb_flow_algorithm_flow_vel_search_limit_low,
              tb_flow_algorithm_flow_vel_search_limit_high,
              tb_flow_algorithm_flow_nyquist_initial_value,
              tb_flow_algorithm_flow_decimation,
              tb_flow_algorithm_flow_window_type,
              tb_flow_algorithm_flow_detrend,
              tb_flow_algorithm_flow_normalization,
              tb_flow_algorithm_flow_differencing,
              tb_flow_algorithm_flow_direction,
              tb_flow_algorithm_flow_window_size_multiplier,
              tb_flow_algorithm_flow_peak_search_mode,
              tb_flow_algorithm_flow_operating_mode,
              tb_flow_algorithm_flow_quality_mode,
              tb_flow_algorithm_flow_bi_direction
          }
      }
}

COMMAND write_tb_flow_algorithm
{
      BLOCK sonar_tb;
      INDEX 22;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_flow_algorithm_flow_sample_freq,
              tb_flow_algorithm_flow_channel_skew,
              tb_flow_algorithm_flow_freq_min,
              tb_flow_algorithm_flow_freq_max,
              tb_flow_algorithm_flow_rate_min,
              tb_flow_algorithm_flow_rate_max,
              tb_flow_algorithm_flow_min_quality,
              tb_flow_algorithm_flow_nyquist_high,
              tb_flow_algorithm_flow_nyquist_low,
              tb_flow_algorithm_flow_centroid_width,
              tb_flow_algorithm_flow_vel_search_limit_low,
              tb_flow_algorithm_flow_vel_search_limit_high,
              tb_flow_algorithm_flow_nyquist_initial_value,
              tb_flow_algorithm_flow_decimation,
              tb_flow_algorithm_flow_window_type,
              tb_flow_algorithm_flow_detrend,
              tb_flow_algorithm_flow_normalization,
              tb_flow_algorithm_flow_differencing,
              tb_flow_algorithm_flow_direction,
              tb_flow_algorithm_flow_window_size_multiplier,
              tb_flow_algorithm_flow_peak_search_mode,
              tb_flow_algorithm_flow_operating_mode,
              tb_flow_algorithm_flow_quality_mode,
              tb_flow_algorithm_flow_bi_direction
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 23 ------*/

COMMAND read_tb_flow_algorithm_dynamic
{
      BLOCK sonar_tb;
      INDEX 23;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_flow_algorithm_dynamic_flow_data_length,
              tb_flow_algorithm_dynamic_flow_window_size,
              tb_flow_algorithm_dynamic_flow_window_overlap,
              tb_flow_algorithm_dynamic_flow_window_averages
          }
      }
}

COMMAND write_tb_flow_algorithm_dynamic
{
      BLOCK sonar_tb;
      INDEX 23;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_flow_algorithm_dynamic_flow_data_length,
              tb_flow_algorithm_dynamic_flow_window_size,
              tb_flow_algorithm_dynamic_flow_window_overlap,
              tb_flow_algorithm_dynamic_flow_window_averages
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 24 ------*/

COMMAND read_tb_flow_calibration
{
      BLOCK sonar_tb;
      INDEX 24;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
                tb_flow_calibration_flow_cal_coeff_c0,
                tb_flow_calibration_flow_cal_coeff_c1,
                tb_flow_calibration_flow_cal_coeff_c2
          }
      }
}

COMMAND write_tb_flow_calibration
{
      BLOCK sonar_tb;
      INDEX 24;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
                tb_flow_calibration_flow_cal_coeff_c0,
                tb_flow_calibration_flow_cal_coeff_c1,
                tb_flow_calibration_flow_cal_coeff_c2
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 25 ------*/

COMMAND read_tb_sos_algorithm
{
      BLOCK sonar_tb;
      INDEX 25;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sos_algorithm_sos_sample_freq,
              tb_sos_algorithm_sos_freq_min,
              tb_sos_algorithm_sos_freq_max,
              tb_sos_algorithm_sos_min,
              tb_sos_algorithm_sos_max,
              tb_sos_algorithm_sos_min_quality,
              tb_sos_algorithm_sos_centroid_width,
              tb_sos_algorithm_sos_frequency_threshold,
              tb_sos_algorithm_sos_min_k,
              tb_sos_algorithm_sos_max_k,
              tb_sos_algorithm_sos_search_limit,
              tb_sos_algorithm_sos_lambda_diam,
              tb_sos_algorithm_sos_total_data,
              tb_sos_algorithm_sos_window_size,
              tb_sos_algorithm_sos_window_overlap,
              tb_sos_algorithm_sos_sub_array_size,
              tb_sos_algorithm_sos_normalization,
              tb_sos_algorithm_sos_differencing,
              tb_sos_algorithm_sos_operating_mode,
              tb_sos_algorithm_sos_selection_threshold,
              tb_sos_algorithm_sos_min_freq_points,
              tb_sos_algorithm_sos_valid_freq_pts_right,
              tb_sos_algorithm_sos_valid_freq_pts_left
          }
      }
}

COMMAND write_tb_sos_algorithm
{
      BLOCK sonar_tb;
      INDEX 25;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_sos_algorithm_sos_sample_freq,
              tb_sos_algorithm_sos_freq_min,
              tb_sos_algorithm_sos_freq_max,
              tb_sos_algorithm_sos_min,
              tb_sos_algorithm_sos_max,
              tb_sos_algorithm_sos_min_quality,
              tb_sos_algorithm_sos_centroid_width,
              tb_sos_algorithm_sos_frequency_threshold,
              tb_sos_algorithm_sos_min_k,
              tb_sos_algorithm_sos_max_k,
              tb_sos_algorithm_sos_search_limit,
              tb_sos_algorithm_sos_lambda_diam,
              tb_sos_algorithm_sos_total_data,
              tb_sos_algorithm_sos_window_size,
              tb_sos_algorithm_sos_window_overlap,
              tb_sos_algorithm_sos_sub_array_size,
              tb_sos_algorithm_sos_normalization,
              tb_sos_algorithm_sos_differencing,
              tb_sos_algorithm_sos_operating_mode,
              tb_sos_algorithm_sos_selection_threshold,
              tb_sos_algorithm_sos_min_freq_points,
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 26 ------*/

COMMAND read_tb_sos_algorithm_dynamic
{
      BLOCK sonar_tb;
      INDEX 26;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sos_algorithm_dynamic_sos_valid_freq_pts_right,
              tb_sos_algorithm_dynamic_sos_valid_freq_pts_left
          }
      }
}

/*--------------------------------------------------------- index 27 ------*/

COMMAND read_tb_spl_acoustic_level
{
      BLOCK sonar_tb;
      INDEX 27;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_spl_acoustic_level_spl_min_freq,
              tb_spl_acoustic_level_spl_max_freq,
              tb_spl_acoustic_level_al_min_freq,
              tb_spl_acoustic_level_al_max_freq,
              tb_spl_acoustic_level_al_fft_points
          }
      }
}

COMMAND write_tb_spl_acoustic_level
{
      BLOCK sonar_tb;
      INDEX 27;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_spl_acoustic_level_spl_min_freq,
              tb_spl_acoustic_level_spl_max_freq,
              tb_spl_acoustic_level_al_min_freq,
              tb_spl_acoustic_level_al_max_freq,
              tb_spl_acoustic_level_al_fft_points
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 28 ------*/

COMMAND read_tb_analog_section
{
      BLOCK sonar_tb;
      INDEX 28;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_analog_section_analog_sensor_input_units_1,
              tb_analog_section_analog_sensor_input_units_2,
              tb_analog_section_analog_sensor_input_scale_1,
              tb_analog_section_analog_sensor_input_scale_2,
              tb_analog_section_analog_sensor_input_offset_1,
              tb_analog_section_analog_sensor_input_offset_2,
              tb_analog_section_analog_sensor_1_1st_order_damping_filter_enable,
              tb_analog_section_analog_sensor_2_1st_order_damping_filter_enable,
              tb_analog_section_analog_sensor_1_damping_tau,
              tb_analog_section_analog_sensor_2_damping_tau
          }
      }
}

COMMAND write_tb_analog_section
{
      BLOCK sonar_tb;
      INDEX 28;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_analog_section_analog_sensor_input_units_1,
              tb_analog_section_analog_sensor_input_units_2,
              tb_analog_section_analog_sensor_input_scale_1,
              tb_analog_section_analog_sensor_input_scale_2,
              tb_analog_section_analog_sensor_input_offset_1,
              tb_analog_section_analog_sensor_input_offset_2,
              tb_analog_section_analog_sensor_1_1st_order_damping_filter_enable,
              tb_analog_section_analog_sensor_2_1st_order_damping_filter_enable,
              tb_analog_section_analog_sensor_1_damping_tau,
              tb_analog_section_analog_sensor_2_damping_tau
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 29 ------*/

COMMAND read_tb_input_units
{
      BLOCK sonar_tb;
      INDEX 29;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_input_units_pressure_input_units,
              tb_input_units_temperature_input_units,
              tb_input_units_input_1_units,
              tb_input_units_input_2_units,
              tb_input_units_input_3_units
          }
      }
}

COMMAND write_tb_input_units
{
      BLOCK sonar_tb;
      INDEX 29;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_input_units_pressure_input_units,
              tb_input_units_temperature_input_units,
              tb_input_units_input_1_units,
              tb_input_units_input_2_units,
              tb_input_units_input_3_units
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 30 ------*/

COMMAND read_tb_flow_nr_filter
{
      BLOCK sonar_tb;
      INDEX 30;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_flow_nr_filter_enable,
              tb_flow_nr_filter_magnitude_selection
          }
      }
}


COMMAND write_tb_flow_nr_filter
{
      BLOCK sonar_tb;
      INDEX 30;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_flow_nr_filter_enable,
              tb_flow_nr_filter_magnitude_selection
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 31 ------*/

COMMAND read_tb_flow_damping_filter
{
      BLOCK sonar_tb;
      INDEX 31;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_flow_damping_filter_flow_1st_order_damping_filter_enable,
              tb_flow_damping_filter_flow_damping_tau
          }
      }
}


COMMAND write_tb_flow_damping_filter
{
      BLOCK sonar_tb;
      INDEX 31;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_flow_damping_filter_flow_1st_order_damping_filter_enable,
              tb_flow_damping_filter_flow_damping_tau
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 32 ------*/

COMMAND read_tb_flow_spike_filter
{
      BLOCK sonar_tb;
      INDEX 32;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_flow_spike_filter_enable,
              tb_flow_spike_filter_no_flow_length,
              tb_flow_spike_filter_length,
              tb_flow_spike_filter_up_count,
              tb_flow_spike_filter_down_count,
              tb_flow_spike_filter_percentage,
              tb_flow_spike_filter_pct_window_len
          }
      }
}


COMMAND write_tb_flow_spike_filter
{
      BLOCK sonar_tb;
      INDEX 32;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_flow_spike_filter_enable,
              tb_flow_spike_filter_no_flow_length,
              tb_flow_spike_filter_length,
              tb_flow_spike_filter_up_count,
              tb_flow_spike_filter_down_count,
              tb_flow_spike_filter_percentage,
              tb_flow_spike_filter_pct_window_len
          }
          REPLY
          {
          }
      }
}


/*--------------------------------------------------------- index 33 ------*/

COMMAND read_tb_gvf_nr_filter
{
      BLOCK sonar_tb;
      INDEX 33;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_gvf_nr_filter_enable,
              tb_gvf_nr_filter_magnitude_selection
          }
      }
}


COMMAND write_tb_gvf_nr_filter
{
      BLOCK sonar_tb;
      INDEX 33;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_gvf_nr_filter_enable,
              tb_gvf_nr_filter_magnitude_selection
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 34 ------*/

COMMAND read_tb_gvf_damping_filter
{
      BLOCK sonar_tb;
      INDEX 34;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_gvf_damping_filter_enable,
              tb_gvf_damping_filter_tau
          }
      }
}


COMMAND write_tb_gvf_damping_filter
{
      BLOCK sonar_tb;
      INDEX 34;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_gvf_damping_filter_enable,
              tb_gvf_damping_filter_tau
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 35 ------*/

COMMAND read_tb_gvf_spike_filter
{
      BLOCK sonar_tb;
      INDEX 35;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_gvf_spike_filter_enable,
              tb_gvf_spike_filter_no_gvf_length,
              tb_gvf_spike_filter_length,
              tb_gvf_spike_filter_up_count,
              tb_gvf_spike_filter_down_count,
              tb_gvf_spike_filter_percentage,
              tb_gvf_spike_filter_filt_pct_window_len
          }
      }
}


COMMAND write_tb_gvf_spike_filter
{
      BLOCK sonar_tb;
      INDEX 35;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_gvf_spike_filter_enable,
              tb_gvf_spike_filter_no_gvf_length,
              tb_gvf_spike_filter_length,
              tb_gvf_spike_filter_up_count,
              tb_gvf_spike_filter_down_count,
              tb_gvf_spike_filter_percentage,
              tb_gvf_spike_filter_filt_pct_window_len
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 36 ------*/

COMMAND read_tb_sensor
{
      BLOCK sonar_tb;
      INDEX 36;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sensor_sensorhead_serial_number,
              tb_sensor_threshold_max,
              tb_sensor_threshold_min,
              tb_sensor_band_temp_rating,
              tb_sensor_band_type,
              tb_sensor_band_active_area,
              tb_sensor_scale_temp_source,
              tb_sensor_scale_comp_temperature,
              tb_sensor_scale_temp_factor
          }
      }
}


COMMAND write_tb_sensor
{
      BLOCK sonar_tb;
      INDEX 36;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_sensor_sensorhead_serial_number,
              tb_sensor_threshold_max,
              tb_sensor_threshold_min,
              tb_sensor_band_temp_rating,
              tb_sensor_band_type,
              tb_sensor_band_active_area,
              tb_sensor_scale_temp_source,
              tb_sensor_scale_comp_temperature,
              tb_sensor_scale_temp_factor
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 37 ------*/

COMMAND read_tb_sensor_spacing
{
      BLOCK sonar_tb;
      INDEX 37;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sensor_spacing_sensor_1_location,
              tb_sensor_spacing_1_2,
              tb_sensor_spacing_1_3,
              tb_sensor_spacing_1_4,
              tb_sensor_spacing_1_5,
              tb_sensor_spacing_1_6,
              tb_sensor_spacing_1_7,
              tb_sensor_spacing_1_8
          }
      }
}


COMMAND write_tb_sensor_spacing
{
      BLOCK sonar_tb;
      INDEX 37;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_sensor_spacing_sensor_1_location,
              tb_sensor_spacing_1_2,
              tb_sensor_spacing_1_3,
              tb_sensor_spacing_1_4,
              tb_sensor_spacing_1_5,
              tb_sensor_spacing_1_6,
              tb_sensor_spacing_1_7,
              tb_sensor_spacing_1_8
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 38 ------*/

COMMAND read_tb_sensor_scale_factor
{
      BLOCK sonar_tb;
      INDEX 38;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sensor_scale_factor_1,
              tb_sensor_scale_factor_2,
              tb_sensor_scale_factor_3,
              tb_sensor_scale_factor_4,
              tb_sensor_scale_factor_5,
              tb_sensor_scale_factor_6,
              tb_sensor_scale_factor_7,
              tb_sensor_scale_factor_8
          }
      }
}


COMMAND write_tb_sensor_scale_factor
{
      BLOCK sonar_tb;
      INDEX 38;
      OPERATION WRITE;
      TRANSACTION
      {
          REQUEST
          {
              tb_sensor_scale_factor_1,
              tb_sensor_scale_factor_2,
              tb_sensor_scale_factor_3,
              tb_sensor_scale_factor_4,
              tb_sensor_scale_factor_5,
              tb_sensor_scale_factor_6,
              tb_sensor_scale_factor_7,
              tb_sensor_scale_factor_8
          }
          REPLY
          {
          }
      }
}

/*--------------------------------------------------------- index 39 ------*/

COMMAND read_tb_measured_values
{
      BLOCK sonar_tb;
      INDEX 39;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_measured_values_flow_quality,
              tb_measured_values_flow_rate_unfiltered,
              tb_measured_values_pressure,
              tb_measured_values_temperature,
              tb_measured_values_sos_quality,
              tb_measured_values_sos_unfiltered,
              tb_measured_values_sos_flow_rate,
              tb_measured_values_sos_flow_qual,
              tb_measured_values_tlf,
              tb_measured_values_total_tlf,
              tb_measured_values_tlf_unfiltered,
              tb_measured_values_analog_4_20ma_input_1,
              tb_measured_values_analog_4_20ma_input_2,
              tb_measured_values_total_flow_fraction,
              tb_measured_values_total_tlf_fraction,
              tb_measured_values_total_flow_carry,
              tb_measured_values_total_tlf_carry,
              tb_measured_values_system_status
          }
      }
}

/*--------------------------------------------------------- index 40 ------*/

COMMAND read_tb_flow_rate
{
      BLOCK sonar_tb;
      INDEX 40;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_flow_rate_value,
              tb_flow_rate_status
          }
      }
}

/*--------------------------------------------------------- index 41 ------*/

COMMAND read_tb_gvf
{
      BLOCK sonar_tb;
      INDEX 41;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_gvf_value,
              tb_gvf_status
          }
      }
}

/*--------------------------------------------------------- index 42 ------*/

COMMAND read_tb_sos
{
      BLOCK sonar_tb;
      INDEX 42;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sos_value,
              tb_sos_status
          }
      }
}

/*--------------------------------------------------------- index 43 ------*/

COMMAND read_tb_sensorhead_temperature
{
      BLOCK sonar_tb;
      INDEX 43;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sensorhead_temperature_value,
              tb_sensorhead_temperature_status
          }
      }
}

/*--------------------------------------------------------- index 44 ------*/

COMMAND read_tb_total_flow
{
      BLOCK sonar_tb;
      INDEX 44;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_total_flow_value,
              tb_total_flow_status
          }
      }
}

/*--------------------------------------------------------- index 45 ------*/

COMMAND read_tb_acoustic_level
{
      BLOCK sonar_tb;
      INDEX 45;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_acoustic_level_value,
              tb_acoustic_level_status
          }
      }
}

/*--------------------------------------------------------- index 46 ------*/

COMMAND read_tb_output_0
{
      BLOCK sonar_tb;
      INDEX 46;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_output_0_value,
              tb_output_0_status
          }
      }
}

/*--------------------------------------------------------- index 47 ------*/

COMMAND read_tb_output_1
{
      BLOCK sonar_tb;
      INDEX 47;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_output_1_value,
              tb_output_1_status
          }
      }
}

/*--------------------------------------------------------- index 48 ------*/

COMMAND read_tb_output_2
{
      BLOCK sonar_tb;
      INDEX 48;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_output_2_value,
              tb_output_2_status
          }
      }
}

/*--------------------------------------------------------- index 49 ------*/

COMMAND read_tb_sensor_max_min
{
      BLOCK sonar_tb;
      INDEX 49;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sensor_max_min_sensor_1_max,
              tb_sensor_max_min_sensor_2_max,
              tb_sensor_max_min_sensor_3_max,
              tb_sensor_max_min_sensor_4_max,
              tb_sensor_max_min_sensor_5_max,
              tb_sensor_max_min_sensor_6_max,
              tb_sensor_max_min_sensor_7_max,
              tb_sensor_max_min_sensor_8_max,
              tb_sensor_max_min_sensor_1_min,
              tb_sensor_max_min_sensor_2_min,
              tb_sensor_max_min_sensor_3_min,
              tb_sensor_max_min_sensor_4_min,
              tb_sensor_max_min_sensor_5_min,
              tb_sensor_max_min_sensor_6_min,
              tb_sensor_max_min_sensor_7_min,
              tb_sensor_max_min_sensor_8_min
          }
      }
}

/*--------------------------------------------------------- index 50 ------*/

COMMAND read_tb_sensor_alpha
{
      BLOCK sonar_tb;
      INDEX 50;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_sensor_alpha_1,
              tb_sensor_alpha_2,
              tb_sensor_alpha_3,
              tb_sensor_alpha_4,
              tb_sensor_alpha_5,
              tb_sensor_alpha_6,
              tb_sensor_alpha_7,
              tb_sensor_alpha_8
          }
      }
}


/*--------------------------------------------------------- index 51 ------*/

COMMAND read_tb_pressure_input
{
      BLOCK sonar_tb;
      INDEX 51;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_pressure_input_value,
              tb_pressure_input_status
          }
      }
}

/*--------------------------------------------------------- index 52 ------*/

COMMAND read_tb_temperature_input
{
      BLOCK sonar_tb;
      INDEX 52;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_temperature_input_value,
              tb_temperature_input_status
          }
      }
}

/*--------------------------------------------------------- index 53 ------*/

COMMAND read_tb_input_1
{
      BLOCK sonar_tb;
      INDEX 53;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_input_1_value,
              tb_input_1_status
          }
      }
}

/*--------------------------------------------------------- index 54 ------*/

COMMAND read_tb_input_2
{
      BLOCK sonar_tb;
      INDEX 54;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_input_2_value,
              tb_input_2_status
          }
      }
}

/*--------------------------------------------------------- index 55 ------*/

COMMAND read_tb_input_3
{
      BLOCK sonar_tb;
      INDEX 55;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_input_3_value,
              tb_input_3_status
          }
      }
}

/*--------------------------------------------------------- index 56 ------*/


COMMAND read_tb_pa_slave_info
{
      BLOCK sonar_tb;
      INDEX 56;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_pa_slave_info_firmware_revision,
              tb_pa_slave_info_node_address,
              tb_pa_slave_info_block_mode_phy,
              tb_pa_slave_info_block_mode_tb,
              tb_pa_slave_info_slave_mode,
              tb_pa_slave_info_slave_ident_number
          }
      }
}

/*--------------------------------------------------------- index 62 ------*/

COMMAND read_tb_comm_state
{
      BLOCK sonar_tb;
      INDEX 57;
      OPERATION READ;
      TRANSACTION
      {
          REQUEST
          {
          }
          REPLY
          {
              tb_comm_state
          }
      }
}

/*-------------------------  See You Next Time-----------------------------*/

